/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type FirewallRuleT = {
  firewallruleId?: string;
  zoneId: string;
  type: string;
  action: string;
  values: Array<string>;
} & {
  [key: string]: any;
};
export declare type CollectionResponseEnvelopeT = {
  data?: Array<any>;
} & {
  [key: string]: any;
};
export declare type WafGroupEnvelopeT = {
  data: WafGroupT;
} & {
  [key: string]: any;
};
export declare type ZoneT = {
  zoneId: string;
  name: string;
  status: string;
} & {
  [key: string]: any;
};
export declare type ZonesEnvelopeT = {
  data: Array<ZoneT>;
} & {
  [key: string]: any;
};
export declare type ItemResponseEnvelopeT = {
  data?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type ZoneEnvelopeT = {
  data: ZoneT;
} & {
  [key: string]: any;
};
export declare type FirewallRuleEnvelopeT = {
  data: FirewallRuleT;
} & {
  [key: string]: any;
};
export declare type FirewallRulesEnvelopeT = {
  data: Array<FirewallRuleT>;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type WafGroupsEnvelopeT = {
  data: Array<WafGroupT>;
} & {
  [key: string]: any;
};
export declare type WafRulesEnvelopeT = {
  data: Array<WafRuleT>;
} & {
  [key: string]: any;
};
export declare type WafGroupT = {
  groupId?: string;
  action?: string;
  mode: string;
  description?: string;
} & {
  [key: string]: any;
};
export declare type WafRuleEnvelopeT = {
  data: WafRuleT;
} & {
  [key: string]: any;
};
export declare type WafRuleT = {
  ruleId?: string;
  groupId?: string;
  action: string;
  defaultAction?: string;
  description?: string;
} & {
  [key: string]: any;
};
export declare type MoneyT = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
