/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type MoneyT = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type CustomPropertiesT = {} & {
  [key: string]: any;
};
export declare type PaymentCardSpecT = {
  cardType?: string;
  checksumVerificationEnabled?: boolean;
  description?: string;
  image?: string;
  name?: string;
  numberLengths?: Array<string>;
  numberPrefixes?: Array<string>;
} & {
  [key: string]: any;
};
export declare type OrderAddressT = {
  address1?: string;
  address2?: string;
  city?: string;
  companyName?: string;
  countryCode?: any;
  firstName?: string;
  fullName?: string;
  id?: string;
  jobTitle?: string;
  lastName?: string;
  phone?: string;
  postBox?: string;
  postalCode?: string;
  salutation?: string;
  secondName?: string;
  stateCode?: string;
  suffix?: string;
  suite?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type BasketsResultT = {
  baskets: Array<BasketT>;
  total: number;
} & {
  [key: string]: any;
};
export declare type PaymentCardT = {
  cardType?: string;
  creditCardExpired?: boolean;
  creditCardToken?: string;
  expirationMonth?: number;
  expirationYear?: number;
  holder?: string;
  issueNumber?: string;
  maskedNumber?: string;
  numberLastDigits?: string;
  validFromMonth?: number;
  validFromYear?: number;
};
export declare type NotesResultT = {
  notes?: Array<NoteT>;
} & {
  [key: string]: any;
};
export declare type ShippingItemT = {
  adjustedTax?: number;
  basePrice?: number;
  itemId?: string;
  itemText?: string;
  price?: number;
  priceAdjustments?: Array<PriceAdjustmentT>;
  priceAfterItemDiscount?: number;
  shipmentId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type DiscountT = {
  amount?: number;
  percentage?: number;
  priceBookId?: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type NoteT = {
  createdBy?: string;
  creationDate?: any;
  id?: string;
  subject?: string;
  text?: string;
};
export declare type CouponItemT = {
  code: string;
  couponItemId?: string;
  statusCode?: string;
  valid?: boolean;
} & {
  [key: string]: any;
};
export declare type PromotionLinkT = {
  calloutMsg?: string;
  name?: string;
  promotionId?: string;
  title?: string;
};
export declare type ShippingPromotionT = {
  calloutMsg?: string;
  promotionId?: string;
  promotionName?: string;
} & {
  [key: string]: any;
};
export declare type ProductItemT = {
  adjustedTax?: number;
  basePrice?: number;
  bonusDiscountLineItemId?: string;
  bonusProductLineItem?: boolean;
  bundledProductItems?: Array<ProductItemT>;
  gift?: boolean;
  giftMessage?: string;
  inventoryId?: string;
  itemId?: string;
  itemText?: string;
  optionItems?: Array<OptionItemT>;
  price?: number;
  priceAdjustments?: Array<PriceAdjustmentT>;
  priceAfterItemDiscount?: number;
  priceAfterOrderDiscount?: number;
  productId?: string;
  productListItem?: ProductListItemReferenceT;
  productName?: string;
  quantity?: number;
  shipmentId?: string;
  shippingItemId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type BasketPaymentInstrumentRequestT = {
  amount?: number;
  bankRoutingNumber?: string;
  giftCertificateCode?: string;
  paymentCard?: OrderPaymentCardRequestT;
  paymentMethodId?: string;
} & {
  [key: string]: any;
};
export declare type OrderPaymentInstrumentT = {
  amount?: number;
  authorizationStatus?: StatusT;
  bankRoutingNumber?: string;
  maskedGiftCertificateCode?: string;
  paymentCard?: PaymentCardT;
  paymentInstrumentId?: string;
  paymentMethodId?: string;
} & {
  [key: string]: any;
};
export declare type BonusDiscountLineItemT = {
  bonusProducts?: Array<ProductDetailsLinkT>;
  couponCode?: string;
  id?: string;
  maxBonusItems?: number;
  promotionId?: string;
} & {
  [key: string]: any;
};
export declare type PaymentMethodResultT = {
  applicablePaymentMethods?: Array<PaymentMethodT>;
} & {
  [key: string]: any;
};
export declare type ShipmentT = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  gift?: boolean;
  giftMessage?: string;
  merchandizeTotalTax?: number;
  productSubTotal?: number;
  productTotal?: number;
  shipmentId?: string;
  shipmentNo?: string;
  shipmentTotal?: number;
  shippingAddress?: OrderAddressT;
  shippingMethod?: ShippingMethodT;
  shippingStatus?: string;
  shippingTotal?: number;
  shippingTotalTax?: number;
  taxTotal?: number;
  trackingNumber?: string;
} & {
  [key: string]: any;
};
export declare type CustomerInfoT = {
  customerId?: string;
  customerName?: string;
  customerNo?: string;
  email: string;
} & {
  [key: string]: any;
};
export declare type SimpleLinkT = {};
export declare type PriceAdjustmentT = {
  appliedDiscount?: DiscountT;
  couponCode?: string;
  createdBy?: string;
  creationDate?: any;
  custom?: boolean;
  itemText?: string;
  lastModified?: any;
  manual?: boolean;
  price?: number;
  priceAdjustmentId?: string;
  promotionId?: string;
  promotionLink?: string;
  reasonCode?: string;
} & {
  [key: string]: any;
};
export declare type ShippingMethodResultT = {
  applicableShippingMethods?: Array<ShippingMethodT>;
  defaultShippingMethodId?: string;
} & {
  [key: string]: any;
};
export declare type ProductDetailsLinkT = {
  productDescription?: string;
  productId: string;
  productName?: string;
  title?: string;
};
export declare type OptionItemT = {
  adjustedTax?: number;
  basePrice?: number;
  bonusDiscountLineItemId?: string;
  bonusProductLineItem?: boolean;
  bundledProductItems?: Array<ProductItemT>;
  gift?: boolean;
  giftMessage?: string;
  inventoryId?: string;
  itemId?: string;
  itemText?: string;
  optionId: string;
  optionItems?: Array<OptionItemT>;
  optionValueId: string;
  price?: number;
  priceAdjustments?: Array<PriceAdjustmentT>;
  priceAfterItemDiscount?: number;
  priceAfterOrderDiscount?: number;
  productId?: string;
  productListItem?: ProductListItemReferenceT;
  productName?: string;
  quantity?: number;
  shipmentId?: string;
  shippingItemId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type ShippingMethodT = {
  description?: string;
  externalShippingMethod?: string;
  id: string;
  name?: string;
  price?: number;
  shippingPromotions?: Array<ShippingPromotionT>;
} & {
  [key: string]: any;
};
export declare type BasketT = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  agentBasket?: boolean;
  basketId?: string;
  billingAddress?: OrderAddressT;
  bonusDiscountLineItems?: Array<BonusDiscountLineItemT>;
  channelType?: string;
  couponItems?: Array<CouponItemT>;
  creationDate?: any;
  currency?: string;
  customerInfo?: CustomerInfoT;
  giftCertificateItems?: Array<GiftCertificateItemT>;
  inventoryReservationExpiry?: any;
  lastModified?: any;
  merchandizeTotalTax?: number;
  notes?: SimpleLinkT;
  orderPriceAdjustments?: Array<PriceAdjustmentT>;
  orderTotal?: number;
  paymentInstruments?: Array<OrderPaymentInstrumentT>;
  productItems?: Array<ProductItemT>;
  productSubTotal?: number;
  productTotal?: number;
  shipments?: Array<ShipmentT>;
  shippingItems?: Array<ShippingItemT>;
  shippingTotal?: number;
  shippingTotalTax?: number;
  sourceCode?: string;
  taxTotal?: number;
  taxation?: string;
} & {
  [key: string]: any;
};
export declare type OrderPaymentInstrumentRequestT = {
  amount?: number;
  bankRoutingNumber?: string;
  giftCertificateCode?: string;
  paymentCard?: OrderPaymentCardRequestT;
  paymentMethodId?: string;
} & {
  [key: string]: any;
};
export declare type GiftCertificateItemT = {
  amount: number;
  giftCertificateItemId?: string;
  message?: string;
  recipientEmail: string;
  recipientName?: string;
  senderName?: string;
  shipmentId?: string;
} & {
  [key: string]: any;
};
export declare type ProductListLinkT = {
  description?: string;
  name?: string;
  public?: boolean;
  title?: string;
  type?: string;
} & {
  [key: string]: any;
};
export declare type OrderT = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  billingAddress?: OrderAddressT;
  bonusDiscountLineItems?: Array<BonusDiscountLineItemT>;
  channelType?: string;
  confirmationStatus?: string;
  couponItems?: Array<CouponItemT>;
  createdBy?: string;
  creationDate?: any;
  currency?: string;
  customerInfo?: CustomerInfoT;
  customerName?: string;
  exportStatus?: string;
  externalOrderStatus?: string;
  giftCertificateItems?: Array<GiftCertificateItemT>;
  globalPartyId?: string;
  lastModified?: any;
  merchandizeTotalTax?: number;
  notes?: SimpleLinkT;
  orderNo?: string;
  orderPriceAdjustments?: Array<PriceAdjustmentT>;
  orderToken?: string;
  orderTotal?: number;
  paymentInstruments?: Array<OrderPaymentInstrumentT>;
  paymentStatus?: string;
  productItems?: Array<ProductItemT>;
  productSubTotal?: number;
  productTotal?: number;
  shipments?: Array<ShipmentT>;
  shippingItems?: Array<ShippingItemT>;
  shippingStatus?: string;
  shippingTotal?: number;
  shippingTotalTax?: number;
  siteId?: string;
  sourceCode?: string;
  status?: string;
  taxTotal?: number;
  taxation?: string;
} & {
  [key: string]: any;
};
export declare type OrderPaymentCardRequestT = {
  cardType?: string;
  creditCardToken?: string;
  expirationMonth?: number;
  expirationYear?: number;
  holder?: string;
  issueNumber?: string;
  maskedNumber?: string;
  validFromMonth?: number;
  validFromYear?: number;
};
export declare type PaymentMethodT = {
  cards?: Array<PaymentCardSpecT>;
  description?: string;
  id: string;
  image?: string;
  name?: string;
  paymentProcessorId?: string;
} & {
  [key: string]: any;
};
export declare type StatusT = {
  code?: string;
  message?: string;
  status?: number;
};
export declare type ProductListItemReferenceT = {
  id: string;
  priority?: number;
  productDetailsLink?: ProductDetailsLinkT;
  productList?: ProductListLinkT;
  public?: boolean;
  purchasedQuantity?: number;
  quantity?: number;
  type?: string;
};
