/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type CustomerAddressT = {
  address1?: string;
  address2?: string;
  addressId: string;
  city?: string;
  companyName?: string;
  countryCode: string;
  creationDate?: any;
  etag?: string;
  firstName?: string;
  fullName?: string;
  jobTitle?: string;
  lastModified?: any;
  lastName: string;
  phone?: string;
  postBox?: string;
  postalCode?: string;
  salutation?: string;
  secondName?: string;
  stateCode?: string;
  suffix?: string;
  suite?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type CustomerGroupSearchResultT = {
  hits?: Array<CustomerGroupT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CustomerListT = {
  id: string;
} & {
  [key: string]: any;
};
export declare type CustomerSearchHitT = {
  data: CustomerT;
  relevance: number;
} & {
  [key: string]: any;
};
export declare type CustomerGroupMembersT = {
  limit?: number;
  data?: Array<CustomerGroupMemberT>;
  offset?: number;
  total?: number;
} & {
  [key: string]: any;
};
export declare type RuleT = {
  description: string;
} & {
  [key: string]: any;
};
export declare type CustomerGroupT = {
  creationDate?: any;
  description?: string;
  id: string;
  inDeletion?: boolean;
  lastModified?: any;
  memberCount?: number;
  rule?: RuleT;
  type?: string;
} & {
  [key: string]: any;
};
export declare type CustomerGroupMemberSearchResultT = {
  hits?: Array<CustomerGroupMemberT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CustomerAddressResultT = {
  limit?: number;
  data?: Array<CustomerAddressT>;
  offset?: number;
  total?: number;
} & {
  [key: string]: any;
};
export declare type CustomerT = {
  birthday?: any;
  companyName?: string;
  creationDate?: any;
  credentials?: CredentialsT;
  customerId?: string;
  customerNo: string;
  email?: string;
  fax?: string;
  firstName?: string;
  gender?: number;
  jobTitle?: string;
  lastLoginTime?: any;
  lastModified?: any;
  lastName: string;
  lastVisitTime?: any;
  phoneBusiness?: string;
  phoneHome?: string;
  phoneMobile?: string;
  preferredLocale?: string;
  previousLoginTime?: any;
  previousVisitTime?: any;
  primaryAddress?: CustomerAddressT;
  salutation?: string;
  secondName?: string;
  suffix?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type CustomerGroupMemberT = {
  active?: boolean;
  creationDate?: any;
  customerNo: string;
  email?: string;
  firstName?: string;
  lastModified?: any;
  lastName: string;
  login?: string;
} & {
  [key: string]: any;
};
export declare type CredentialsT = {
  enabled?: boolean;
  locked?: boolean;
  login: string;
  passwordQuestion?: string;
} & {
  [key: string]: any;
};
export declare type CustomerSearchResultT = {
  hits: Array<CustomerSearchHitT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ErrorT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
