/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  CustomerAddressT,
  CustomerProductListResultT,
  CustomerProductListItemPurchaseT,
  OptionValueT,
  MasterT,
  OrderAddressT,
  PublicProductListResultT,
  BasketsResultT,
  TrustedSystemAuthRequestT,
  ResetPasswordRequestT,
  PaymentCardT,
  ShippingItemT,
  DiscountT,
  ResetPasswordTokenT,
  CouponItemT,
  ShippingPromotionT,
  VariationAttributeT,
  ProductListShippingAddressT,
  ProductItemT,
  CustomerProductListRegistrantT,
  PublicProductListInfoT,
  CustomerPaymentCardRequestT,
  RecommendationTypeT,
  OrderPaymentInstrumentT,
  ProductTypeT,
  PaymentBankAccountT,
  RecommendationT,
  VariantT,
  BonusDiscountLineItemT,
  CustomerPaymentInstrumentT,
  ShipmentT,
  CustomerInfoT,
  VariationGroupT,
  SimpleLinkT,
  PaymentBankAccountRequestT,
  PriceAdjustmentT,
  PublicProductListItemT,
  ProductDetailsLinkT,
  ProductLinkT,
  OptionItemT,
  ShippingMethodT,
  ProductListEventT,
  PasswordChangeRequestT,
  AuthRequestT,
  InventoryT,
  CustomerProductListT,
  BasketT,
  CustomerPaymentInstrumentRequestT,
  ImageGroupT,
  CustomerRegistrationT,
  CustomerT,
  PublicProductListT,
  OptionT,
  CustomerOrderResultT,
  GiftCertificateItemT,
  CustomerAddressInfoT,
  ResetPasswordTokenRequestT,
  ProductListLinkT,
  ProductListRegistrantT,
  OrderT,
  ProductT,
  ImageT,
  VariationAttributeValueT,
  ProductPromotionT,
  BundledProductT,
  StatusT,
  CustomerProductListItemT,
  ProductListItemReferenceT,
  ErrorResponseT,
  SearchRequestT,
  PaginatedSearchResultT,
  SimpleSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT
} from "./shopperCustomers.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class ShopperCustomers extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Registers a new customer. The mandatory data are the credentials, profile last name, and email. This requires a JSON Web Token (JWT) which needs to be obtained using the POST /customers/auth API with type \"guest\".
   *
   * If you would like to get a raw Response object use the other registerCustomer function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerT.
   */
  registerCustomer(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerRegistrationT;
  }): Promise<CustomerT>;
  /**
   * Registers a new customer. The mandatory data are the credentials, profile last name, and email. This requires a JSON Web Token (JWT) which needs to be obtained using the POST /customers/auth API with type \"guest\".
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise.
   */
  registerCustomer<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerRegistrationT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerT>;
  /**
   * Invalidates the JSON Web Token (JWT) provided in the header.
   *
   * If you would like to get a raw Response object use the other invalidateCustomerAuth function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  invalidateCustomerAuth(options?: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Invalidates the JSON Web Token (JWT) provided in the header.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  invalidateCustomerAuth<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
    * Obtains a new JSON Web Token (JWT)for a guest or registered
customer. Tokens are returned as an HTTP Authorization:Bearer response
header entry. These kinds of request are supported, as specified by the
type:

Type guest - creates a guest (non-authenticated) customer
and returns a token for the customer.
Request Body for guest : \{\"type\": \"guest\"\}
Type credentials - authenticates credentials passed in the
HTTP Authorization:Basic request header, returning a token for a
successfully authenticated customer, otherwise it throws an
AuthenticationFailedException.
Request Body for guest : \{\"type\": \"credentials\"\}
Type refresh - examines the token passed in the HTTP
Authorization:Bearer request header and when valid returns a new token
with an updated expiry time.
Request Body for guest : \{\"type\": \"refresh\"\}

For a request of type credentials:

Updates profile attributes for the customer (for example,
\"last-visited\").
Handles the maximum number of failed login attempts.

About JWT The token contains 3 sections:

The header section (specifies token type and algorithm used),
the payload section (contains customer information, client ID,
issue, and expiration time),
finally the signature section records the token signature.

A token is created and returned to the client whenever a registered
customer logs in (type \"credentials\") or a guest customer requests it (type
\"guest\"). The token is returned in the response header as
Authorization: Bearer --token--

The client has to include the token in the request header as
Authorization: Bearer --token--
in any follow-up request. The server declines any follow-up requests
without a token or which cannot be verified based on the token signature
or expiration time. A token nearing its expiration time should be
exchanged for a new one (type \"refresh\").

See \"API Usage \> JWT\" for more details on using JWT as an authentication
mechanism.
    *
    * If you would like to get a raw Response object use the other authorizeCustomer function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param clientId - Client ID for application identification
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CustomerT.
    */
  authorizeCustomer(options: {
    parameters?: {
      organizationId?: string;
      clientId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: AuthRequestT;
  }): Promise<CustomerT>;
  /**
    * Obtains a new JSON Web Token (JWT)for a guest or registered
customer. Tokens are returned as an HTTP Authorization:Bearer response
header entry. These kinds of request are supported, as specified by the
type:

Type guest - creates a guest (non-authenticated) customer
and returns a token for the customer.
Request Body for guest : \{\"type\": \"guest\"\}
Type credentials - authenticates credentials passed in the
HTTP Authorization:Basic request header, returning a token for a
successfully authenticated customer, otherwise it throws an
AuthenticationFailedException.
Request Body for guest : \{\"type\": \"credentials\"\}
Type refresh - examines the token passed in the HTTP
Authorization:Bearer request header and when valid returns a new token
with an updated expiry time.
Request Body for guest : \{\"type\": \"refresh\"\}

For a request of type credentials:

Updates profile attributes for the customer (for example,
\"last-visited\").
Handles the maximum number of failed login attempts.

About JWT The token contains 3 sections:

The header section (specifies token type and algorithm used),
the payload section (contains customer information, client ID,
issue, and expiration time),
finally the signature section records the token signature.

A token is created and returned to the client whenever a registered
customer logs in (type \"credentials\") or a guest customer requests it (type
\"guest\"). The token is returned in the response header as
Authorization: Bearer --token--

The client has to include the token in the request header as
Authorization: Bearer --token--
in any follow-up request. The server declines any follow-up requests
without a token or which cannot be verified based on the token signature
or expiration time. A token nearing its expiration time should be
exchanged for a new one (type \"refresh\").

See \"API Usage \> JWT\" for more details on using JWT as an authentication
mechanism.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param clientId - Client ID for application identification
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise.
    */
  authorizeCustomer<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        clientId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: AuthRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerT>;
  /**
   * Obtain the JSON Web Token (JWT) for registered customers whose credentials are stored using a third party system. Accepts loginId and clientId, returns a customer object in the response body and the JWT generated against the clientId in the response header.
   *
   * If you would like to get a raw Response object use the other authorizeTrustedSystem function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerT.
   */
  authorizeTrustedSystem(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: TrustedSystemAuthRequestT;
  }): Promise<CustomerT>;
  /**
   * Obtain the JSON Web Token (JWT) for registered customers whose credentials are stored using a third party system. Accepts loginId and clientId, returns a customer object in the response body and the JWT generated against the clientId in the response header.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise.
   */
  authorizeTrustedSystem<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: TrustedSystemAuthRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerT>;
  /**
   * Reset customer password.
   *
   * If you would like to get a raw Response object use the other resetPassword function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   */
  resetPassword(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ResetPasswordRequestT;
  }): Promise<void>;
  /**
   * Reset customer password.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  resetPassword<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ResetPasswordRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Get reset password token.
   *
   * If you would like to get a raw Response object use the other getResetPasswordToken function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ResetPasswordTokenT.
   */
  getResetPasswordToken(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ResetPasswordTokenRequestT;
  }): Promise<ResetPasswordTokenT>;
  /**
   * Get reset password token.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ResetPasswordTokenT otherwise.
   */
  getResetPasswordToken<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ResetPasswordTokenRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ResetPasswordTokenT>;
  /**
   * Gets a customer with all existing addresses and payment instruments associated with the requested customer.
   *
   * If you would like to get a raw Response object use the other getCustomer function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerT.
   */
  getCustomer(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerT>;
  /**
   * Gets a customer with all existing addresses and payment instruments associated with the requested customer.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise.
   */
  getCustomer<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerT>;
  /**
   * Updates a customer.
   *
   * If you would like to get a raw Response object use the other updateCustomer function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerT.
   */
  updateCustomer(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerT;
  }): Promise<CustomerT>;
  /**
   * Updates a customer.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise.
   */
  updateCustomer<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerT>;
  /**
   * Creates a new address with the given name for the given customer.
   *
   * If you would like to get a raw Response object use the other createCustomerAddress function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerAddressT.
   */
  createCustomerAddress(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerAddressT;
  }): Promise<CustomerAddressT>;
  /**
   * Creates a new address with the given name for the given customer.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressT otherwise.
   */
  createCustomerAddress<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerAddressT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerAddressT>;
  /**
   * Retrieves a customer's address by address name.
   *
   * If you would like to get a raw Response object use the other getCustomerAddress function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param addressName - The name of the address to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerAddressT.
   */
  getCustomerAddress(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      addressName: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerAddressT>;
  /**
   * Retrieves a customer's address by address name.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param addressName - The name of the address to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressT otherwise.
   */
  getCustomerAddress<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        addressName: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerAddressT>;
  /**
   * Deletes a customer's address by address name.
   *
   * If you would like to get a raw Response object use the other removeCustomerAddress function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param addressName - The name of the address to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  removeCustomerAddress(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      addressName: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes a customer's address by address name.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param addressName - The name of the address to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  removeCustomerAddress<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        addressName: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates a customer's address by address name.
   *
   * If you would like to get a raw Response object use the other updateCustomerAddress function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param addressName - The name of the address to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerAddressT.
   */
  updateCustomerAddress(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      addressName: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerAddressT;
  }): Promise<CustomerAddressT>;
  /**
   * Updates a customer's address by address name.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param addressName - The name of the address to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressT otherwise.
   */
  updateCustomerAddress<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        addressName: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerAddressT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerAddressT>;
  /**
   * Gets the baskets of a customer.
   *
   * If you would like to get a raw Response object use the other getCustomerBaskets function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type BasketsResultT.
   */
  getCustomerBaskets(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<BasketsResultT>;
  /**
   * Gets the baskets of a customer.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type BasketsResultT otherwise.
   */
  getCustomerBaskets<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : BasketsResultT>;
  /**
   * Returns a pageable list of all customer's orders. The default page size is 10.
   *
   * If you would like to get a raw Response object use the other getCustomerOrders function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param crossSites -
   * @param from -
   * @param until -
   * @param status -
   * @param siteId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 10.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerOrderResultT.
   */
  getCustomerOrders(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      crossSites?: boolean;
      from?: string;
      until?: string;
      status?: string;
      siteId?: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerOrderResultT>;
  /**
   * Returns a pageable list of all customer's orders. The default page size is 10.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param crossSites -
   * @param from -
   * @param until -
   * @param status -
   * @param siteId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 10.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerOrderResultT otherwise.
   */
  getCustomerOrders<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        crossSites?: boolean;
        from?: string;
        until?: string;
        status?: string;
        siteId?: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerOrderResultT>;
  /**
   * Updates the customer's password.
   *
   * If you would like to get a raw Response object use the other updateCustomerPassword function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   */
  updateCustomerPassword(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: PasswordChangeRequestT;
  }): Promise<void>;
  /**
   * Updates the customer's password.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  updateCustomerPassword<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: PasswordChangeRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Adds a payment instrument to the customer information.
   *
   * If you would like to get a raw Response object use the other createCustomerPaymentInstrument function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerPaymentInstrumentT.
   */
  createCustomerPaymentInstrument(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerPaymentInstrumentRequestT;
  }): Promise<CustomerPaymentInstrumentT>;
  /**
   * Adds a payment instrument to the customer information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerPaymentInstrumentT otherwise.
   */
  createCustomerPaymentInstrument<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerPaymentInstrumentRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerPaymentInstrumentT>;
  /**
   * Deletes a customer's payment instrument.
   *
   * If you would like to get a raw Response object use the other deleteCustomerPaymentInstrument function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param paymentInstrumentId - The ID of the payment instrument to be retrievedCustomer.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteCustomerPaymentInstrument(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes a customer's payment instrument.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param paymentInstrumentId - The ID of the payment instrument to be retrievedCustomer.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteCustomerPaymentInstrument<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Retrieves a customer's payment instrument by its ID.
   *
   * If you would like to get a raw Response object use the other getCustomerPaymentInstrument function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param paymentInstrumentId - The ID of the payment instrument to be retrievedCustomer.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerPaymentInstrumentT.
   */
  getCustomerPaymentInstrument(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      paymentInstrumentId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerPaymentInstrumentT>;
  /**
   * Retrieves a customer's payment instrument by its ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param paymentInstrumentId - The ID of the payment instrument to be retrievedCustomer.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerPaymentInstrumentT otherwise.
   */
  getCustomerPaymentInstrument<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        paymentInstrumentId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerPaymentInstrumentT>;
  /**
   * Returns all customer product lists.
   *
   * If you would like to get a raw Response object use the other getCustomerProductLists function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerProductListResultT.
   */
  getCustomerProductLists(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerProductListResultT>;
  /**
   * Returns all customer product lists.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListResultT otherwise.
   */
  getCustomerProductLists<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListResultT>;
  /**
   * Creates a customer product list.
   *
   * If you would like to get a raw Response object use the other createCustomerProductList function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerProductListT.
   */
  createCustomerProductList(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerProductListT;
  }): Promise<CustomerProductListT>;
  /**
   * Creates a customer product list.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListT otherwise.
   */
  createCustomerProductList<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerProductListT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListT>;
  /**
   * Deletes a customer product list.
   *
   * If you would like to get a raw Response object use the other deleteCustomerProductList function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteCustomerProductList(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes a customer product list.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteCustomerProductList<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Returns a customer product list of the given customer and the items in the list.
   *
   * If you would like to get a raw Response object use the other getCustomerProductList function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerProductListT.
   */
  getCustomerProductList(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerProductListT>;
  /**
   * Returns a customer product list of the given customer and the items in the list.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListT otherwise.
   */
  getCustomerProductList<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListT>;
  /**
   * Changes a product list. Changeable properties are the name, description, and if the list is public.
   *
   * If you would like to get a raw Response object use the other updateCustomerProductList function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CustomerProductListT.
   */
  updateCustomerProductList(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerProductListT;
  }): Promise<CustomerProductListT>;
  /**
   * Changes a product list. Changeable properties are the name, description, and if the list is public.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListT otherwise.
   */
  updateCustomerProductList<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerProductListT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListT>;
  /**
    * Adds an item to the customer's product list. Considered values from the request body are:

type: A valid type, mandatory. This is the type of the item to be added to the customer's product.
list.
priority: This is the priority of the item to be added to the customer's product list.
public: This is the flag whether the item to be added to the customer's product list is public.
product_id: A valid product ID, used for product item type only. This is the ID (SKU)
of the product related to the item to be added to the customer's product list. It is mandatory for
product item type, and it must be a valid product id, otherwise
ProductListProductIdMissingException or ProductListProductNotFoundException
will be thrown.
quantity: Used for product item type only. This is the quantity of the item to be
added to the customer's product list.
custom properties in the form c_\<CUSTOM_NAME\>: The custom property must correspond to a custom
attribute (\<CUSTOM_NAME\>) defined for ProductListItem. The value of this property must be valid for the
type of custom attribute defined for ProductListItem.
    *
    * If you would like to get a raw Response object use the other createCustomerProductListItem function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param customerId - The customer ID.
    * @param listId - The product list ID.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CustomerProductListItemT.
    */
  createCustomerProductListItem(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerProductListItemT;
  }): Promise<CustomerProductListItemT>;
  /**
    * Adds an item to the customer's product list. Considered values from the request body are:

type: A valid type, mandatory. This is the type of the item to be added to the customer's product.
list.
priority: This is the priority of the item to be added to the customer's product list.
public: This is the flag whether the item to be added to the customer's product list is public.
product_id: A valid product ID, used for product item type only. This is the ID (SKU)
of the product related to the item to be added to the customer's product list. It is mandatory for
product item type, and it must be a valid product id, otherwise
ProductListProductIdMissingException or ProductListProductNotFoundException
will be thrown.
quantity: Used for product item type only. This is the quantity of the item to be
added to the customer's product list.
custom properties in the form c_\<CUSTOM_NAME\>: The custom property must correspond to a custom
attribute (\<CUSTOM_NAME\>) defined for ProductListItem. The value of this property must be valid for the
type of custom attribute defined for ProductListItem.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param customerId - The customer ID.
    * @param listId - The product list ID.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListItemT otherwise.
    */
  createCustomerProductListItem<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerProductListItemT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListItemT>;
  /**
   * Removes an item from a customer product list.
   *
   * If you would like to get a raw Response object use the other deleteCustomerProductListItem function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param itemId - The ID of the product list item to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteCustomerProductListItem(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Removes an item from a customer product list.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param itemId - The ID of the product list item to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteCustomerProductListItem<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Returns an item of a customer product list and the actual product details like image, availability and price.
   *
   * If you would like to get a raw Response object use the other getCustomerProductListItem function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param itemId - The ID of the product list item to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CustomerProductListItemT.
   */
  getCustomerProductListItem(options?: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CustomerProductListItemT>;
  /**
   * Returns an item of a customer product list and the actual product details like image, availability and price.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param customerId - The customer ID.
   * @param listId - The product list ID.
   * @param itemId - The ID of the product list item to update.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListItemT otherwise.
   */
  getCustomerProductListItem<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListItemT>;
  /**
    * Updates an item of a customer's product list.
Considered values from the request body are:

priority: This is the priority of the customer's product list item.
public: This is the flag whether the customer's product list item is public.
quantity: This is the quantity of
the customer's product list item. Used for product item type only.
custom properties in the form c_\<CUSTOM_NAME\>: The custom property
must correspond to a custom attribute (\<CUSTOM_NAME\>) defined for ProductListItem.
The value of this property must be valid for the type of custom attribute defined for ProductListItem.
    *
    * If you would like to get a raw Response object use the other updateCustomerProductListItem function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param customerId - The customer ID.
    * @param listId - The product list ID.
    * @param itemId - The ID of the product list item to update.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CustomerProductListItemT.
    */
  updateCustomerProductListItem(options: {
    parameters?: {
      organizationId?: string;
      customerId: string;
      listId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CustomerProductListItemT;
  }): Promise<CustomerProductListItemT>;
  /**
    * Updates an item of a customer's product list.
Considered values from the request body are:

priority: This is the priority of the customer's product list item.
public: This is the flag whether the customer's product list item is public.
quantity: This is the quantity of
the customer's product list item. Used for product item type only.
custom properties in the form c_\<CUSTOM_NAME\>: The custom property
must correspond to a custom attribute (\<CUSTOM_NAME\>) defined for ProductListItem.
The value of this property must be valid for the type of custom attribute defined for ProductListItem.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param customerId - The customer ID.
    * @param listId - The product list ID.
    * @param itemId - The ID of the product list item to update.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerProductListItemT otherwise.
    */
  updateCustomerProductListItem<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        customerId: string;
        listId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CustomerProductListItemT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CustomerProductListItemT>;
  /**
   * Retrieves all public product lists as defined by the given search term (for example, email OR first name and last name).
   *
   * If you would like to get a raw Response object use the other getPublicProductListsBySearchTerm function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param email - The email address of the customer the product lists belong to.
   * @param firstName - The first name of the customer the product lists belong to.
   * @param lastName - The last name of the customer the product lists belong to.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type PublicProductListResultT.
   */
  getPublicProductListsBySearchTerm(options?: {
    parameters?: {
      organizationId?: string;
      email?: string;
      firstName?: string;
      lastName?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<PublicProductListResultT>;
  /**
   * Retrieves all public product lists as defined by the given search term (for example, email OR first name and last name).
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param email - The email address of the customer the product lists belong to.
   * @param firstName - The first name of the customer the product lists belong to.
   * @param lastName - The last name of the customer the product lists belong to.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type PublicProductListResultT otherwise.
   */
  getPublicProductListsBySearchTerm<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        email?: string;
        firstName?: string;
        lastName?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : PublicProductListResultT>;
  /**
   * Retrieves a public product list by ID and the items under that product list.
   *
   * If you would like to get a raw Response object use the other getPublicProductList function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param listId - The ID of the list.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type PublicProductListT.
   */
  getPublicProductList(options?: {
    parameters?: {
      organizationId?: string;
      listId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<PublicProductListT>;
  /**
   * Retrieves a public product list by ID and the items under that product list.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param listId - The ID of the list.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type PublicProductListT otherwise.
   */
  getPublicProductList<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        listId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : PublicProductListT>;
  /**
   * Retrieves an item from a public product list and the actual product details like product, image, availability and price.
   *
   * If you would like to get a raw Response object use the other getProductListItem function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param listId - The ID of the list.
   * @param itemId - The ID of the item.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type PublicProductListItemT.
   */
  getProductListItem(options?: {
    parameters?: {
      organizationId?: string;
      listId: string;
      itemId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<PublicProductListItemT>;
  /**
   * Retrieves an item from a public product list and the actual product details like product, image, availability and price.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param listId - The ID of the list.
   * @param itemId - The ID of the item.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type PublicProductListItemT otherwise.
   */
  getProductListItem<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        listId: string;
        itemId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : PublicProductListItemT>;
}
declare namespace ShopperCustomers {
  type CustomerAddress = CustomerAddressT;
  type CustomerProductListResult = CustomerProductListResultT;
  type CustomerProductListItemPurchase = CustomerProductListItemPurchaseT;
  type OptionValue = OptionValueT;
  type Master = MasterT;
  type OrderAddress = OrderAddressT;
  type PublicProductListResult = PublicProductListResultT;
  type BasketsResult = BasketsResultT;
  type TrustedSystemAuthRequest = TrustedSystemAuthRequestT;
  type ResetPasswordRequest = ResetPasswordRequestT;
  type PaymentCard = PaymentCardT;
  type ShippingItem = ShippingItemT;
  type Discount = DiscountT;
  type ResetPasswordToken = ResetPasswordTokenT;
  type CouponItem = CouponItemT;
  type ShippingPromotion = ShippingPromotionT;
  type VariationAttribute = VariationAttributeT;
  type ProductListShippingAddress = ProductListShippingAddressT;
  type ProductItem = ProductItemT;
  type CustomerProductListRegistrant = CustomerProductListRegistrantT;
  type PublicProductListInfo = PublicProductListInfoT;
  type CustomerPaymentCardRequest = CustomerPaymentCardRequestT;
  type RecommendationType = RecommendationTypeT;
  type OrderPaymentInstrument = OrderPaymentInstrumentT;
  type ProductType = ProductTypeT;
  type PaymentBankAccount = PaymentBankAccountT;
  type Recommendation = RecommendationT;
  type Variant = VariantT;
  type BonusDiscountLineItem = BonusDiscountLineItemT;
  type CustomerPaymentInstrument = CustomerPaymentInstrumentT;
  type Shipment = ShipmentT;
  type CustomerInfo = CustomerInfoT;
  type VariationGroup = VariationGroupT;
  type SimpleLink = SimpleLinkT;
  type PaymentBankAccountRequest = PaymentBankAccountRequestT;
  type PriceAdjustment = PriceAdjustmentT;
  type PublicProductListItem = PublicProductListItemT;
  type ProductDetailsLink = ProductDetailsLinkT;
  type ProductLink = ProductLinkT;
  type OptionItem = OptionItemT;
  type ShippingMethod = ShippingMethodT;
  type ProductListEvent = ProductListEventT;
  type PasswordChangeRequest = PasswordChangeRequestT;
  type AuthRequest = AuthRequestT;
  type Inventory = InventoryT;
  type CustomerProductList = CustomerProductListT;
  type Basket = BasketT;
  type CustomerPaymentInstrumentRequest = CustomerPaymentInstrumentRequestT;
  type ImageGroup = ImageGroupT;
  type CustomerRegistration = CustomerRegistrationT;
  type Customer = CustomerT;
  type PublicProductList = PublicProductListT;
  type Option = OptionT;
  type CustomerOrderResult = CustomerOrderResultT;
  type GiftCertificateItem = GiftCertificateItemT;
  type CustomerAddressInfo = CustomerAddressInfoT;
  type ResetPasswordTokenRequest = ResetPasswordTokenRequestT;
  type ProductListLink = ProductListLinkT;
  type ProductListRegistrant = ProductListRegistrantT;
  type Order = OrderT;
  type Product = ProductT;
  type Image = ImageT;
  type VariationAttributeValue = VariationAttributeValueT;
  type ProductPromotion = ProductPromotionT;
  type BundledProduct = BundledProductT;
  type Status = StatusT;
  type CustomerProductListItem = CustomerProductListItemT;
  type ProductListItemReference = ProductListItemReferenceT;
  type ErrorResponse = ErrorResponseT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type SimpleSearchResult = SimpleSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
}
export = ShopperCustomers;
