/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type CustomerAddressT = {
  address1?: string;
  address2?: string;
  addressId: string;
  city?: string;
  companyName?: string;
  countryCode: string;
  creationDate?: any;
  firstName?: string;
  fullName?: string;
  jobTitle?: string;
  lastModified?: any;
  lastName: string;
  phone?: string;
  postBox?: string;
  postalCode?: string;
  preferred?: boolean;
  salutation?: string;
  secondName?: string;
  stateCode?: string;
  suffix?: string;
  suite?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type CustomerProductListResultT = {
  limit: number;
  data: Array<CustomerProductListT>;
  total: number;
} & {
  [key: string]: any;
};
export declare type CustomerProductListItemPurchaseT = {
  id: string;
  orderNo: string;
  productListItemId: string;
  purchaserName: string;
  quantity: number;
} & {
  [key: string]: any;
};
export declare type OptionValueT = {
  default?: boolean;
  id: string;
  name?: string;
  price?: number;
} & {
  [key: string]: any;
};
export declare type MasterT = {
  masterId: string;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type OrderAddressT = {
  address1: string;
  address2?: string;
  city: string;
  companyName?: string;
  countryCode: string;
  firstName: string;
  fullName?: string;
  id?: string;
  jobTitle?: string;
  lastName: string;
  phone?: string;
  postBox?: string;
  postalCode: string;
  salutation?: string;
  secondName?: string;
  stateCode?: string;
  suffix?: string;
  suite?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type PublicProductListResultT = {
  limit: number;
  data: Array<PublicProductListInfoT>;
  total: number;
} & {
  [key: string]: any;
};
export declare type BasketsResultT = {
  baskets: Array<BasketT>;
  total: number;
} & {
  [key: string]: any;
};
export declare type TrustedSystemAuthRequestT = {
  clientId: string;
  login: string;
} & {
  [key: string]: any;
};
export declare type ResetPasswordRequestT = {
  resetToken: string;
  login: string;
  newPassword: string;
} & {
  [key: string]: any;
};
export declare type PaymentCardT = {
  cardType: string;
  creditCardExpired?: boolean;
  creditCardToken?: string;
  expirationMonth?: number;
  expirationYear?: number;
  holder?: string;
  issueNumber?: string;
  maskedNumber?: string;
  numberLastDigits?: string;
  validFromMonth?: number;
  validFromYear?: number;
} & {
  [key: string]: any;
};
export declare type ShippingItemT = {
  adjustedTax: number;
  basePrice: number;
  itemId: string;
  itemText: string;
  price: number;
  priceAdjustments: Array<PriceAdjustmentT>;
  priceAfterItemDiscount: number;
  shipmentId: string;
  tax: number;
  taxBasis: number;
  taxClassId: string;
  taxRate: number;
} & {
  [key: string]: any;
};
export declare type DiscountT = {
  amount?: number;
  percentage?: number;
  priceBookId?: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type ResetPasswordTokenT = {
  login: string;
  email: string;
  resetToken: string;
  expiresInMinutes: number;
} & {
  [key: string]: any;
};
export declare type CouponItemT = {
  code: string;
  couponItemId?: string;
  statusCode?: string;
  valid?: boolean;
} & {
  [key: string]: any;
};
export declare type ShippingPromotionT = {
  calloutMsg: string;
  promotionId: string;
  promotionName: string;
} & {
  [key: string]: any;
};
export declare type VariationAttributeT = {
  id: string;
  name?: string;
  values?: Array<VariationAttributeValueT>;
} & {
  [key: string]: any;
};
export declare type ProductListShippingAddressT = {
  addressId: string;
  city?: string;
  firstName?: string;
  lastName?: string;
} & {
  [key: string]: any;
};
export declare type ProductItemT = {
  adjustedTax?: number;
  basePrice?: number;
  bonusDiscountLineItemId?: string;
  bonusProductLineItem?: boolean;
  bundledProductItems?: Array<ProductItemT>;
  gift?: boolean;
  giftMessage?: string;
  inventoryId?: string;
  itemId?: string;
  itemText?: string;
  optionItems?: Array<OptionItemT>;
  price?: number;
  priceAdjustments?: Array<PriceAdjustmentT>;
  priceAfterItemDiscount?: number;
  priceAfterOrderDiscount?: number;
  productId?: string;
  productListItem?: ProductListItemReferenceT;
  productName?: string;
  quantity: number;
  shipmentId?: string;
  shippingItemId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type CustomerProductListRegistrantT = {
  email: string;
  firstName: string;
  lastName: string;
  role: string;
} & {
  [key: string]: any;
};
export declare type PublicProductListInfoT = {
  description?: string;
  id: string;
  name?: string;
  title: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type CustomerPaymentCardRequestT = {
  cardType: string;
  creditCardToken?: string;
  expirationMonth: number;
  expirationYear: number;
  holder: string;
  issueNumber: string;
  number: string;
  validFromMonth: number;
  validFromYear: number;
} & {
  [key: string]: any;
};
export declare type RecommendationTypeT = {
  displayValue: string;
  value: number;
} & {
  [key: string]: any;
};
export declare type OrderPaymentInstrumentT = {
  amount: number;
  authorizationStatus: StatusT;
  bankRoutingNumber: string;
  maskedGiftCertificateCode: string;
  paymentBankAccount: PaymentBankAccountT;
  paymentCard: PaymentCardT;
  paymentInstrumentId: string;
  paymentMethodId: string;
} & {
  [key: string]: any;
};
export declare type ProductTypeT = {
  bundle: boolean;
  item: boolean;
  master: boolean;
  option: boolean;
  set: boolean;
  variant: boolean;
  variationGroup: boolean;
} & {
  [key: string]: any;
};
export declare type PaymentBankAccountT = {
  driversLicenseLastDigits?: string;
  driversLicenseStateCode?: string;
  holder?: string;
  maskedDriversLicense?: string;
  maskedNumber?: string;
  numberLastDigits?: string;
} & {
  [key: string]: any;
};
export declare type RecommendationT = {
  calloutMsg?: string;
  image?: ImageT;
  longDescription?: string;
  name?: string;
  recommendationType: RecommendationTypeT;
  recommendedItemId?: string;
  recommendedItemLink?: string;
  shortDescription?: string;
} & {
  [key: string]: any;
};
export declare type VariantT = {
  orderable?: boolean;
  price?: number;
  productId: string;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type BonusDiscountLineItemT = {
  bonusProducts: Array<ProductDetailsLinkT>;
  couponCode: string;
  id: string;
  maxBonusItems: number;
  promotionId: string;
} & {
  [key: string]: any;
};
export declare type CustomerPaymentInstrumentT = {
  bankRoutingNumber?: string;
  creationDate?: any;
  lastModified?: any;
  maskedGiftCertificateCode?: string;
  paymentBankAccount: PaymentBankAccountT;
  paymentCard: PaymentCardT;
  paymentInstrumentId: string;
  paymentMethodId: string;
} & {
  [key: string]: any;
};
export declare type ShipmentT = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  gift?: boolean;
  giftMessage?: string;
  merchandizeTotalTax?: number;
  productSubTotal?: number;
  productTotal?: number;
  shipmentId?: string;
  shipmentNo?: string;
  shipmentTotal?: number;
  shippingAddress?: OrderAddressT;
  shippingMethod?: ShippingMethodT;
  shippingStatus: string;
  shippingTotal?: number;
  shippingTotalTax?: number;
  taxTotal?: number;
  trackingNumber?: string;
} & {
  [key: string]: any;
};
export declare type CustomerInfoT = {
  customerId?: string;
  customerName?: string;
  customerNo: string;
  email: string;
} & {
  [key: string]: any;
};
export declare type VariationGroupT = {
  orderable: boolean;
  price: number;
  productId: string;
  variationValues: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type SimpleLinkT = {
  link: string;
} & {
  [key: string]: any;
};
export declare type PaymentBankAccountRequestT = {
  driversLicense: string;
  driversLicenseStateCode: string;
  holder: string;
  number: string;
} & {
  [key: string]: any;
};
export declare type PriceAdjustmentT = {
  appliedDiscount: DiscountT;
  couponCode: string;
  createdBy: string;
  creationDate: any;
  custom: boolean;
  itemText: string;
  lastModified: any;
  manual: boolean;
  price: number;
  priceAdjustmentId: string;
  promotionId: string;
  promotionLink: string;
  reasonCode: string;
} & {
  [key: string]: any;
};
export declare type PublicProductListItemT = {
  id: string;
  priority: number;
  product?: ProductT;
  type: string;
} & {
  [key: string]: any;
};
export declare type ProductDetailsLinkT = {
  productDescription?: string;
  productId: string;
  productName?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type ProductLinkT = {
  sourceProductId: string;
  sourceProductLink: string;
  targetProductId: string;
  targetProductLink: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type OptionItemT = {
  adjustedTax?: number;
  basePrice?: number;
  bonusDiscountLineItemId?: string;
  bonusProductLineItem?: boolean;
  bundledProductItems?: Array<ProductItemT>;
  gift?: boolean;
  giftMessage?: string;
  inventoryId?: string;
  itemId?: string;
  itemText?: string;
  optionId: string;
  optionItems?: Array<OptionItemT>;
  optionValueId: string;
  price?: number;
  priceAdjustments?: Array<PriceAdjustmentT>;
  priceAfterItemDiscount?: number;
  priceAfterOrderDiscount?: number;
  productId?: string;
  productListItem?: ProductListItemReferenceT;
  productName?: string;
  quantity?: number;
  shipmentId?: string;
  shippingItemId?: string;
  tax?: number;
  taxBasis?: number;
  taxClassId?: string;
  taxRate?: number;
} & {
  [key: string]: any;
};
export declare type ShippingMethodT = {
  description?: string;
  externalShippingMethod?: string;
  id: string;
  name?: string;
  price?: number;
  shippingPromotions?: Array<ShippingPromotionT>;
} & {
  [key: string]: any;
};
export declare type ProductListEventT = {
  city?: string;
  country?: string;
  date?: any;
  state?: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type PasswordChangeRequestT = {
  currentPassword: string;
  password: string;
} & {
  [key: string]: any;
};
export declare type AuthRequestT = {
  type?: string;
} & {
  [key: string]: any;
};
export declare type InventoryT = {
  ats?: number;
  backorderable?: boolean;
  id: string;
  inStockDate?: any;
  orderable?: boolean;
  preorderable?: boolean;
  stockLevel?: number;
} & {
  [key: string]: any;
};
export declare type CustomerProductListT = {
  coRegistrant?: CustomerProductListRegistrantT;
  creationDate?: any;
  currentShippingAddressInfo?: CustomerAddressInfoT;
  customerProductListItems?: Array<CustomerProductListItemT>;
  description?: string;
  event?: ProductListEventT;
  id?: string;
  lastModified?: any;
  name?: string;
  postEventShippingAddressInfo?: CustomerAddressInfoT;
  productListShippingAddress?: ProductListShippingAddressT;
  public?: boolean;
  registrant?: CustomerProductListRegistrantT;
  shippingAddressInfo?: CustomerAddressInfoT;
  type?: string;
} & {
  [key: string]: any;
};
export declare type BasketT = {
  adjustedMerchandizeTotalTax: number;
  adjustedShippingTotalTax: number;
  agentBasket: boolean;
  basketId: string;
  billingAddress: OrderAddressT;
  bonusDiscountLineItems: Array<BonusDiscountLineItemT>;
  channelType: string;
  couponItems: Array<CouponItemT>;
  creationDate: any;
  currency: string;
  customerInfo: CustomerInfoT;
  giftCertificateItems: Array<GiftCertificateItemT>;
  inventoryReservationExpiry: any;
  lastModified: any;
  merchandizeTotalTax: number;
  notes: SimpleLinkT;
  orderPriceAdjustments: Array<PriceAdjustmentT>;
  orderTotal: number;
  paymentInstruments: Array<OrderPaymentInstrumentT>;
  productItems: Array<ProductItemT>;
  productSubTotal: number;
  productTotal: number;
  shipments: Array<ShipmentT>;
  shippingItems: Array<ShippingItemT>;
  shippingTotal: number;
  shippingTotalTax: number;
  sourceCode: string;
  taxTotal: number;
  taxation: string;
} & {
  [key: string]: any;
};
export declare type CustomerPaymentInstrumentRequestT = {
  bankRoutingNumber: string;
  giftCertificateCode: string;
  paymentBankAccount?: PaymentBankAccountRequestT;
  paymentCard: CustomerPaymentCardRequestT;
  paymentMethodId: string;
} & {
  [key: string]: any;
};
export declare type ImageGroupT = {
  images: Array<ImageT>;
  variationAttributes?: Array<VariationAttributeT>;
  viewType: string;
} & {
  [key: string]: any;
};
export declare type CustomerRegistrationT = {
  customer: CustomerT;
  password: string;
} & {
  [key: string]: any;
};
export declare type CustomerT = {
  addresses?: Array<CustomerAddressT>;
  authType?: string;
  birthday?: any;
  companyName?: string;
  creationDate?: any;
  customerId?: string;
  customerNo?: string;
  email?: string;
  enabled?: boolean;
  fax?: string;
  firstName?: string;
  gender?: number;
  jobTitle?: string;
  lastLoginTime?: any;
  lastModified?: any;
  lastName?: string;
  lastVisitTime?: any;
  login?: string;
  note?: string;
  paymentInstruments?: Array<CustomerPaymentInstrumentT>;
  phoneBusiness?: string;
  phoneHome?: string;
  phoneMobile?: string;
  preferredLocale?: string;
  previousLoginTime?: any;
  previousVisitTime?: any;
  salutation?: string;
  secondName?: string;
  suffix?: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type PublicProductListT = {
  coRegistrant?: ProductListRegistrantT;
  creationDate?: any;
  description?: string;
  event?: ProductListEventT;
  id: string;
  lastModified?: any;
  name?: string;
  productListItems?: Array<PublicProductListItemT>;
  productListShippingAddress?: ProductListShippingAddressT;
  public: boolean;
  registrant?: ProductListRegistrantT;
  type: string;
} & {
  [key: string]: any;
};
export declare type OptionT = {
  description?: string;
  id: string;
  image?: string;
  name?: string;
  values?: Array<OptionValueT>;
} & {
  [key: string]: any;
};
export declare type CustomerOrderResultT = {
  limit: number;
  data: Array<OrderT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type GiftCertificateItemT = {
  amount: number;
  giftCertificateItemId?: string;
  message?: string;
  recipientEmail: string;
  recipientName?: string;
  senderName?: string;
  shipmentId?: string;
} & {
  [key: string]: any;
};
export declare type CustomerAddressInfoT = {
  addressId: string;
  title: string;
} & {
  [key: string]: any;
};
export declare type ResetPasswordTokenRequestT = {
  login: string;
} & {
  [key: string]: any;
};
export declare type ProductListLinkT = {
  description: string;
  link: string;
  name: string;
  public: boolean;
  title: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type ProductListRegistrantT = {
  firstName: string;
  lastName: string;
  role: string;
} & {
  [key: string]: any;
};
export declare type OrderT = {
  adjustedMerchandizeTotalTax?: number;
  adjustedShippingTotalTax?: number;
  billingAddress?: OrderAddressT;
  bonusDiscountLineItems?: Array<BonusDiscountLineItemT>;
  channelType?: string;
  confirmationStatus: string;
  couponItems?: Array<CouponItemT>;
  createdBy?: string;
  creationDate?: any;
  currency?: string;
  customerInfo?: CustomerInfoT;
  customerName?: string;
  exportStatus: string;
  externalOrderStatus?: string;
  giftCertificateItems?: Array<GiftCertificateItemT>;
  globalPartyId?: string;
  lastModified?: any;
  merchandizeTotalTax?: number;
  notes?: SimpleLinkT;
  orderNo?: string;
  orderPriceAdjustments?: Array<PriceAdjustmentT>;
  orderToken?: string;
  orderTotal?: number;
  paymentInstruments?: Array<OrderPaymentInstrumentT>;
  paymentStatus: string;
  productItems?: Array<ProductItemT>;
  productSubTotal?: number;
  productTotal?: number;
  shipments?: Array<ShipmentT>;
  shippingItems?: Array<ShippingItemT>;
  shippingStatus: string;
  shippingTotal?: number;
  shippingTotalTax?: number;
  siteId?: string;
  sourceCode?: string;
  status: string;
  taxTotal?: number;
  taxation?: string;
} & {
  [key: string]: any;
};
export declare type ProductT = {
  brand?: string;
  bundledProducts?: Array<BundledProductT>;
  currency?: string;
  ean?: string;
  fetchDate?: number;
  id: string;
  imageGroups?: Array<ImageGroupT>;
  inventories?: Array<InventoryT>;
  inventory?: InventoryT;
  longDescription?: string;
  manufacturerName?: string;
  manufacturerSku?: string;
  master?: MasterT;
  minOrderQuantity?: number;
  name?: string;
  options?: Array<OptionT>;
  pageDescription?: string;
  pageKeywords?: string;
  pageTitle?: string;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
  primaryCategoryId?: string;
  productLinks?: Array<ProductLinkT>;
  productPromotions?: Array<ProductPromotionT>;
  recommendations?: Array<RecommendationT>;
  setProducts?: Array<ProductT>;
  shortDescription?: string;
  stepQuantity?: number;
  type?: ProductTypeT;
  unit?: string;
  upc?: string;
  validFrom?: any;
  validTo?: any;
  variants?: Array<VariantT>;
  variationAttributes?: Array<VariationAttributeT>;
  variationGroups?: Array<VariationGroupT>;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type ImageT = {
  alt?: string;
  disBaseLink?: string;
  link: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type VariationAttributeValueT = {
  description?: string;
  image?: ImageT;
  imageSwatch?: ImageT;
  name?: string;
  orderable?: boolean;
  value: string;
} & {
  [key: string]: any;
};
export declare type ProductPromotionT = {
  calloutMsg: string;
  promotionId: string;
  promotionalPrice: number;
} & {
  [key: string]: any;
};
export declare type BundledProductT = {
  id: string;
  product: ProductT;
  quantity: number;
} & {
  [key: string]: any;
};
export declare type StatusT = {
  code: string;
  message: string;
  status: number;
} & {
  [key: string]: any;
};
export declare type CustomerProductListItemT = {
  id?: string;
  priority: number;
  product?: ProductT;
  productId?: string;
  public: boolean;
  purchasedQuantity?: number;
  quantity: number;
  type?: string;
} & {
  [key: string]: any;
};
export declare type ProductListItemReferenceT = {
  id: string;
  priority?: number;
  productList?: ProductListLinkT;
  public?: boolean;
  purchasedQuantity?: number;
  quantity?: number;
  type?: string;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
