/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  TimeOfDayT,
  CampaignT,
  PromotionCampaignAssignmentT,
  TagT,
  PromotionT,
  PromotionAssignmentInformationT,
  ScheduleT,
  PromotionCampaignAssignmentSearchResultT,
  RecurrenceT,
  PromotionAbtestGroupAssignmentT,
  MoneyT,
  SimpleSearchResultT,
  SearchRequestT,
  PaginatedSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT,
  ErrorResponseT
} from "./assignments.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class Assignments extends BaseClient {
  constructor(config: ClientConfig);
  /**
    * Searches for promotion campaign assignments.

The promotion campaign assignment search document contains a search object that allows filtering on various attributes.

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped into different buckets.

The following is a list of searchable attributes with their corresponding buckets:
  
  main:
  
  | Attribute | Type |
  |-----------|--------|
  | rank| Integer |
  | startDate | Date |
  | endDate | Date |
   
  campaign:
  
  | Attribute | Type |
  |-----------|--------|
  | campaign| String |
   
  promotion:
  
  | Attribute | Type |
  |-----------|--------|
  | promotionId| String |
  | description | String |
  | enabled | Boolean |
   
  special handling:
  
  | Attribute | Type |
  |-----------|--------|
  | couponId| String |
   
Only fields in the same bucket can be joined using a disjunction (or). For instance, when joining campaignId and rank, only a conjunction (and) is allowed, whereas promotionId and description can be joined to each other using a disjunction because they are in the same bucket. Special handling fields must always use conjunctions. If the field is used in a disjunction that violates this rule, an exception is thrown.
   

Expands that can be applied for the search request:
  
  - promotion
  - campaign
   
Note that only searchable attributes can be used in sorting.

    *
    * If you would like to get a raw Response object use the other assignmentsSearch function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type PromotionCampaignAssignmentSearchResultT.
    */
  assignmentsSearch(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<PromotionCampaignAssignmentSearchResultT>;
  /**
    * Searches for promotion campaign assignments.

The promotion campaign assignment search document contains a search object that allows filtering on various attributes.

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped into different buckets.

The following is a list of searchable attributes with their corresponding buckets:
  
  main:
  
  | Attribute | Type |
  |-----------|--------|
  | rank| Integer |
  | startDate | Date |
  | endDate | Date |
   
  campaign:
  
  | Attribute | Type |
  |-----------|--------|
  | campaign| String |
   
  promotion:
  
  | Attribute | Type |
  |-----------|--------|
  | promotionId| String |
  | description | String |
  | enabled | Boolean |
   
  special handling:
  
  | Attribute | Type |
  |-----------|--------|
  | couponId| String |
   
Only fields in the same bucket can be joined using a disjunction (or). For instance, when joining campaignId and rank, only a conjunction (and) is allowed, whereas promotionId and description can be joined to each other using a disjunction because they are in the same bucket. Special handling fields must always use conjunctions. If the field is used in a disjunction that violates this rule, an exception is thrown.
   

Expands that can be applied for the search request:
  
  - promotion
  - campaign
   
Note that only searchable attributes can be used in sorting.

    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionCampaignAssignmentSearchResultT otherwise.
    */
  assignmentsSearch<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : PromotionCampaignAssignmentSearchResultT
  >;
}
declare namespace Assignments {
  type TimeOfDay = TimeOfDayT;
  type Campaign = CampaignT;
  type PromotionCampaignAssignment = PromotionCampaignAssignmentT;
  type Tag = TagT;
  type Promotion = PromotionT;
  type PromotionAssignmentInformation = PromotionAssignmentInformationT;
  type Schedule = ScheduleT;
  type PromotionCampaignAssignmentSearchResult = PromotionCampaignAssignmentSearchResultT;
  type Recurrence = RecurrenceT;
  type PromotionAbtestGroupAssignment = PromotionAbtestGroupAssignmentT;
  type Money = MoneyT;
  type SimpleSearchResult = SimpleSearchResultT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
  type ErrorResponse = ErrorResponseT;
}
export = Assignments;
