/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type TimeOfDayT = {
  timeFrom: string;
  timeTo: string;
} & {
  [key: string]: any;
};
export declare type CampaignT = {
  campaignId: string;
  coupons?: Array<string>;
  creationDate?: any;
  customerGroups?: Array<string>;
  description?: string;
  enabled?: boolean;
  endDate?: any;
  lastModified?: any;
  sourceCodeGroups?: Array<string>;
  startDate?: any;
} & {
  [key: string]: any;
};
export declare type PromotionCampaignAssignmentT = {
  campaign: CampaignT;
  campaignId: string;
  coupons: Array<string>;
  customerGroups: Array<string>;
  description: string;
  enabled: boolean;
  promotion: PromotionT;
  promotionId: string;
  rank: number;
  schedule: ScheduleT;
  sourceCodeGroups: Array<string>;
} & {
  [key: string]: any;
};
export declare type TagT = {
  tagId: string;
} & {
  [key: string]: any;
};
export declare type PromotionT = {
  archived?: boolean;
  assignmentInformation?: PromotionAssignmentInformationT;
  creationDate?: any;
  currencyCode?: string;
  disableGloballyExcluded?: boolean;
  enabled?: boolean;
  exclusivity: string;
  id: string;
  lastModified?: any;
  name?: {} & {
    [key: string]: any;
  };
  promotionClass?: string;
  tags?: Array<TagT>;
} & {
  [key: string]: any;
};
export declare type PromotionAssignmentInformationT = {
  abtestId: string;
  abtestSegmentId: string;
  active: boolean;
  activeAbtestAssignments: Array<PromotionAbtestGroupAssignmentT>;
  activeCampaignAssignments: Array<PromotionCampaignAssignmentT>;
  campaignId: string;
  enabled: boolean;
  endDate: any;
  schedule: ScheduleT;
  scheduleType: string;
  startDate: any;
  upcomingAbtestAssignments: Array<PromotionAbtestGroupAssignmentT>;
  upcomingCampaignAssignments: Array<PromotionCampaignAssignmentT>;
} & {
  [key: string]: any;
};
export declare type ScheduleT = {
  endDate: any;
  recurrence: RecurrenceT;
  startDate: any;
} & {
  [key: string]: any;
};
export declare type PromotionCampaignAssignmentSearchResultT = {
  hits: Array<PromotionCampaignAssignmentT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type RecurrenceT = {
  dayOfWeek: Array<string>;
  timeOfDay: TimeOfDayT;
} & {
  [key: string]: any;
};
export declare type PromotionAbtestGroupAssignmentT = {
  abtestDescription: string;
  abtestId: string;
  enabled: boolean;
  schedule: ScheduleT;
  segmentDescription: string;
  segmentId: string;
} & {
  [key: string]: any;
};
export declare type MoneyT = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
