/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  CouponRedemptionSearchResultT,
  CouponCodesT,
  RedemptionLimitsT,
  CouponRedemptionT,
  RedemptionLimitPerPeriodT,
  CouponCodeT,
  CouponSearchResultT,
  CouponT,
  CouponMultiCodesRequestT,
  CouponSystemCodeConfigT,
  ErrorResponseT,
  MoneyT,
  SimpleSearchResultT,
  SearchRequestT,
  PaginatedSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT
} from "./coupons.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class Coupons extends BaseClient {
  constructor(config: ClientConfig);
  /**
    * Searches for coupons.

 The Coupon Search document contains a search object that allows filtering on various attributes.

 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 coupon_id - String
 description - String
 type - one of \{\"single_code\", \"multiple_codes\", \"system_codes\"\}
 enabled - boolean
 

 Note that only searchable attributes can be used in sorting.
    *
    * If you would like to get a raw Response object use the other couponsSearch function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CouponSearchResultT.
    */
  couponsSearch(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<CouponSearchResultT>;
  /**
    * Searches for coupons.

 The Coupon Search document contains a search object that allows filtering on various attributes.

 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 coupon_id - String
 description - String
 type - one of \{\"single_code\", \"multiple_codes\", \"system_codes\"\}
 enabled - boolean
 

 Note that only searchable attributes can be used in sorting.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CouponSearchResultT otherwise.
    */
  couponsSearch<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CouponSearchResultT>;
  /**
    * Searches for coupon redemptions.

The Coupon Redemption Search document contains a search object that allows filtering on various attributes.


The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

   code - String
   coupon_id - String
   customer_email - String
   order_no - String


Note that only searchable attributes can be used in sorting.

If the role to which the user belongs does not have View_Coupon_Codes permission, then the coupon codes returned will be masked.
    *
    * If you would like to get a raw Response object use the other couponRedemptionsSearch function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CouponRedemptionSearchResultT.
    */
  couponRedemptionsSearch(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<CouponRedemptionSearchResultT>;
  /**
    * Searches for coupon redemptions.

The Coupon Redemption Search document contains a search object that allows filtering on various attributes.


The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

   code - String
   coupon_id - String
   customer_email - String
   order_no - String


Note that only searchable attributes can be used in sorting.

If the role to which the user belongs does not have View_Coupon_Codes permission, then the coupon codes returned will be masked.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CouponRedemptionSearchResultT otherwise.
    */
  couponRedemptionsSearch<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CouponRedemptionSearchResultT>;
  /**
   * Delete a coupon by ID.
   *
   * If you would like to get a raw Response object use the other deleteCoupon function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteCoupon(options?: {
    parameters?: {
      organizationId?: string;
      couponId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Delete a coupon by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteCoupon<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        couponId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
    * Returns coupon information for the given coupon ID.
 If the role to which the user belongs does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    *
    * If you would like to get a raw Response object use the other getCoupon function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param select - The fields that you want to select.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type CouponT.
    */
  getCoupon(options?: {
    parameters?: {
      organizationId?: string;
      couponId: string;
      select?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CouponT>;
  /**
    * Returns coupon information for the given coupon ID.
 If the role to which the user belongs does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param select - The fields that you want to select.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CouponT otherwise.
    */
  getCoupon<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        couponId: string;
        select?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CouponT>;
  /**
   * Updates the coupon with the specified information.
   *
   * If you would like to get a raw Response object use the other updateCoupon function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CouponT.
   */
  updateCoupon(options: {
    parameters?: {
      organizationId?: string;
      couponId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CouponT;
  }): Promise<CouponT>;
  /**
   * Updates the coupon with the specified information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CouponT otherwise.
   */
  updateCoupon<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        couponId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CouponT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CouponT>;
  /**
    * Creates a coupon using the information provided. If a coupon exists with the same unique identifier,
 the coupon is replaced completely.
    *
    * If you would like to get a raw Response object use the other createCoupon function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CouponT.
    */
  createCoupon(options: {
    parameters?: {
      organizationId?: string;
      couponId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CouponT;
  }): Promise<CouponT>;
  /**
    * Creates a coupon using the information provided. If a coupon exists with the same unique identifier,
 the coupon is replaced completely.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CouponT otherwise.
    */
  createCoupon<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        couponId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CouponT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CouponT>;
  /**
    * Get the coupon codes for the given coupon.

 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    *
    * If you would like to get a raw Response object use the other getCouponCodes function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param offset -
    * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 25.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type CouponCodesT.
    */
  getCouponCodes(options?: {
    parameters?: {
      organizationId?: string;
      couponId: string;
      offset?: number;
      limit?: number;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CouponCodesT>;
  /**
    * Get the coupon codes for the given coupon.

 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param offset -
    * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 25.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CouponCodesT otherwise.
    */
  getCouponCodes<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        couponId: string;
        offset?: number;
        limit?: number;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CouponCodesT>;
  /**
   * Add or delete (modify) multiple codes to and from the supplied coupon.
   *
   * If you would like to get a raw Response object use the other updateCouponCodes function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param delete - Pass as true to delete the passed codes.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type void.
   */
  updateCouponCodes(options: {
    parameters?: {
      organizationId?: string;
      couponId: string;
      delete?: boolean;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CouponMultiCodesRequestT;
  }): Promise<void>;
  /**
   * Add or delete (modify) multiple codes to and from the supplied coupon.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param delete - Pass as true to delete the passed codes.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  updateCouponCodes<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        couponId: string;
        delete?: boolean;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CouponMultiCodesRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
}
declare namespace Coupons {
  type CouponRedemptionSearchResult = CouponRedemptionSearchResultT;
  type CouponCodes = CouponCodesT;
  type RedemptionLimits = RedemptionLimitsT;
  type CouponRedemption = CouponRedemptionT;
  type RedemptionLimitPerPeriod = RedemptionLimitPerPeriodT;
  type CouponCode = CouponCodeT;
  type CouponSearchResult = CouponSearchResultT;
  type Coupon = CouponT;
  type CouponMultiCodesRequest = CouponMultiCodesRequestT;
  type CouponSystemCodeConfig = CouponSystemCodeConfigT;
  type ErrorResponse = ErrorResponseT;
  type Money = MoneyT;
  type SimpleSearchResult = SimpleSearchResultT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
}
export = Coupons;
