/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type CouponRedemptionSearchResultT = {
  hits: Array<CouponRedemptionT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CouponCodesT = {
  limit?: number;
  data: Array<CouponCodeT>;
  offset?: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type RedemptionLimitsT = {
  limitPerCode: number;
  limitPerCustomer: number;
  limitPerTimeFrame: RedemptionLimitPerPeriodT;
} & {
  [key: string]: any;
};
export declare type CouponRedemptionT = {
  code: string;
  couponId: string;
  creationDate: any;
  customerEmail: string;
  orderNo: string;
  viewOrderUrl: string;
} & {
  [key: string]: any;
};
export declare type RedemptionLimitPerPeriodT = {
  limit: number;
  redemptionTimeFrame: number;
} & {
  [key: string]: any;
};
export declare type CouponCodeT = {
  code: string;
  issued: boolean;
  redemptionCount: number;
} & {
  [key: string]: any;
};
export declare type CouponSearchResultT = {
  hits: Array<CouponT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type CouponT = {
  couponId: string;
  creationDate?: any;
  description?: string;
  enabled: boolean;
  exportedCodeCount?: number;
  lastModified?: any;
  redemptionCount?: number;
  redemptionLimits?: RedemptionLimitsT;
  singleCode?: string;
  systemCodesConfig?: CouponSystemCodeConfigT;
  totalCodesCount?: number;
  type: string;
} & {
  [key: string]: any;
};
export declare type CouponMultiCodesRequestT = {
  codes: Array<string>;
} & {
  [key: string]: any;
};
export declare type CouponSystemCodeConfigT = {
  codePrefix: string;
  numberOfCodes: number;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type MoneyT = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
