/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  MoneyT,
  CategoryProductAssignmentSearchResultT,
  ProductOptionT,
  MasterT,
  CategorySearchResultT,
  CategoryT,
  VariationAttributeT,
  CatalogCategoryIdT,
  CategoriesT,
  SortingRuleT,
  ProductTypeT,
  VariantT,
  VariationGroupT,
  ProductOptionValueT,
  VariationAttributesT,
  CategoryLinksT,
  MarkupTextT,
  ImageGroupT,
  CatalogsT,
  CategoryLinkT,
  MediaFileT,
  VariationAttributeValuesT,
  CatalogSearchResultT,
  SiteT,
  ProductOptionsT,
  ProductT,
  CategoryProductAssignmentT,
  VariationAttributeValueT,
  ProductOptionValuesT,
  CustomerListLinkT,
  PathRecordT,
  CatalogT,
  SortingRuleStepT,
  ErrorResponseT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  SimpleSearchResultT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  SearchRequestT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  PaginatedSearchResultT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT
} from "./catalogs.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class Catalogs extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Action to get the list of catalog IDs with no filtering.
   *
   * If you would like to get a raw Response object use the other getCatalogs function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CatalogsT.
   */
  getCatalogs(options?: {
    parameters?: {
      organizationId?: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CatalogsT>;
  /**
   * Action to get the list of catalog IDs with no filtering.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CatalogsT otherwise.
   */
  getCatalogs<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CatalogsT>;
  /**
   * Gets the catalog with the specified information.
   *
   * If you would like to get a raw Response object use the other getCatalog function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CatalogT.
   */
  getCatalog(options?: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CatalogT>;
  /**
   * Gets the catalog with the specified information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CatalogT otherwise.
   */
  getCatalog<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CatalogT>;
  /**
   * Updates the catalog with the specified information.
   *
   * If you would like to get a raw Response object use the other updateCatalog function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CatalogT.
   */
  updateCatalog(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CatalogT;
  }): Promise<CatalogT>;
  /**
   * Updates the catalog with the specified information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CatalogT otherwise.
   */
  updateCatalog<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CatalogT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CatalogT>;
  /**
   * Action to get all the categories with no filtering.
   *
   * If you would like to get a raw Response object use the other getCategoriesFromCatalog function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type CategoriesT.
   */
  getCategoriesFromCatalog(options?: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CategoriesT>;
  /**
   * Action to get all the categories with no filtering.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CategoriesT otherwise.
   */
  getCategoriesFromCatalog<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategoriesT>;
  /**
   * Deletes the category by catalog ID and category ID.
   *
   * If you would like to get a raw Response object use the other deleteCategoryFromCatalog function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param categoryId - The ID of the category to be created.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteCategoryFromCatalog(options?: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes the category by catalog ID and category ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param categoryId - The ID of the category to be created.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteCategoryFromCatalog<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
    * Action to read an existing category within a catalog. By default, the server
also returns the first level of sub-categories, but you can specify another level by setting the levels
parameter. Using a large value for levels may cause performance
issues in case of a large and deep category tree.
    *
    * If you would like to get a raw Response object use the other getCategoryFromCatalog function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param levels - The level number
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type CategoryT.
    */
  getCategoryFromCatalog(options?: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
      levels?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CategoryT>;
  /**
    * Action to read an existing category within a catalog. By default, the server
also returns the first level of sub-categories, but you can specify another level by setting the levels
parameter. Using a large value for levels may cause performance
issues in case of a large and deep category tree.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param levels - The level number
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryT otherwise.
    */
  getCategoryFromCatalog<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
        levels?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategoryT>;
  /**
   * Updates a catalog category using the information provided.
   *
   * If you would like to get a raw Response object use the other updateCategoryInCatalog function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param categoryId - The ID of the category to be created.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CategoryT.
   */
  updateCategoryInCatalog(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CategoryT;
  }): Promise<CategoryT>;
  /**
   * Updates a catalog category using the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param categoryId - The ID of the category to be created.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CategoryT otherwise.
   */
  updateCategoryInCatalog<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CategoryT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategoryT>;
  /**
   * Creates a catalog category using the information provided.
   *
   * If you would like to get a raw Response object use the other createCategoryInCatalog function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param categoryId - The ID of the category to be created.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type CategoryT | CategoryT.
   */
  createCategoryInCatalog(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CategoryT;
  }): Promise<CategoryT | CategoryT>;
  /**
   * Creates a catalog category using the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param catalogId - The ID of the requested catalog.
   * @param categoryId - The ID of the category to be created.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CategoryT | CategoryT otherwise.
   */
  createCategoryInCatalog<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CategoryT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategoryT | CategoryT>;
  /**
    * Searches for category product assignments.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 product_id - String
 product_name - String
 online_flag - Boolean
 searchable - Boolean
 valid_from - DateTime
 valid_to - DateTime
 creation_date - DateTime
 
 
 Sortable Fields:
 
 product_id - String
 product_name - String
 position - Double
 creation_date - DateTime
 
 
 Expansions that can be applied for the search request:
 
 product_base - String - This expand will enable retrieval of the following basic Product information:
 product_images - String - to fetch preview image and image groups specified for the given product
 product_all_images - String - to fetch preview image and image groups specified for the product plus images for its variants and variation groups
 product_variations - String to fetch variations related information, version 17.8+
 product_availability - String to fetch availability related information, version 17.8+
 product_categories - String to fetch category related information, version 17.8+
 product_prices - String to fetch prices related information, version 17.8+
 product_options - String to fetch options related information, version 17.8+
 product_all - String to fetch all expanded information, version 17.8+

  
      brand
      ean
   link
      long_description
   manufacturer_name
   manufacturer_sku
      name
   page_description
   page_keywords
   page_title
   searchable
      short_description
   type
   unit
      upc
  
 
    *
    * If you would like to get a raw Response object use the other searchProductsAssignedToCategory function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param siteId - The site ID of the context for the product being queried for in the request.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CategoryProductAssignmentSearchResultT.
    */
  searchProductsAssignedToCategory(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<CategoryProductAssignmentSearchResultT>;
  /**
    * Searches for category product assignments.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 product_id - String
 product_name - String
 online_flag - Boolean
 searchable - Boolean
 valid_from - DateTime
 valid_to - DateTime
 creation_date - DateTime
 
 
 Sortable Fields:
 
 product_id - String
 product_name - String
 position - Double
 creation_date - DateTime
 
 
 Expansions that can be applied for the search request:
 
 product_base - String - This expand will enable retrieval of the following basic Product information:
 product_images - String - to fetch preview image and image groups specified for the given product
 product_all_images - String - to fetch preview image and image groups specified for the product plus images for its variants and variation groups
 product_variations - String to fetch variations related information, version 17.8+
 product_availability - String to fetch availability related information, version 17.8+
 product_categories - String to fetch category related information, version 17.8+
 product_prices - String to fetch prices related information, version 17.8+
 product_options - String to fetch options related information, version 17.8+
 product_all - String to fetch all expanded information, version 17.8+

  
      brand
      ean
   link
      long_description
   manufacturer_name
   manufacturer_sku
      name
   page_description
   page_keywords
   page_title
   searchable
      short_description
   type
   unit
      upc
  
 
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param siteId - The site ID of the context for the product being queried for in the request.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryProductAssignmentSearchResultT otherwise.
    */
  searchProductsAssignedToCategory<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : CategoryProductAssignmentSearchResultT
  >;
  /**
    * Retrieves a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5, and delete assignment for product B,
  the products end up A, B, C at positions 1, null, 7.5.
    *
    * If you would like to get a raw Response object use the other getAssignedProductFromCategory function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type CategoryProductAssignmentT.
    */
  getAssignedProductFromCategory(options?: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<CategoryProductAssignmentT>;
  /**
    * Retrieves a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5, and delete assignment for product B,
  the products end up A, B, C at positions 1, null, 7.5.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryProductAssignmentT otherwise.
    */
  getAssignedProductFromCategory<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategoryProductAssignmentT>;
  /**
    * Removes a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5 and delete assignment for product B,
the products end up A, B, C at positions 1, null, 7.5.
    *
    * If you would like to get a raw Response object use the other unassignProductFromCategory function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type void.
    */
  unassignProductFromCategory(options?: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
    * Removes a category product assignment.


For example, if we have products A, B, C at positions 1, 2, 7.5 and delete assignment for product B,
the products end up A, B, C at positions 1, null, 7.5.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    */
  unassignProductFromCategory<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
    * Updates the category product assignment with the specified information, such as position.
  As the assigned position n is a normalized target position, we'll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C, D at positions 1, 2, 3, 4 and update product A with a  new position of 3,
the end result is B, C, A, D with order of positions 1, 2, 3, 4. If we then update product C to no position,
the end result is B, A, D, C with order of positions 1, 2, 3, null.

If there are n existing positioned assignments, updating product to position \>= n will end with a new assignment with a position such that the order of positions is maintained.
    *
    * If you would like to get a raw Response object use the other updateProductCategoryAssignment function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CategoryProductAssignmentT.
    */
  updateProductCategoryAssignment(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CategoryProductAssignmentT;
  }): Promise<CategoryProductAssignmentT>;
  /**
    * Updates the category product assignment with the specified information, such as position.
  As the assigned position n is a normalized target position, we'll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C, D at positions 1, 2, 3, 4 and update product A with a  new position of 3,
the end result is B, C, A, D with order of positions 1, 2, 3, 4. If we then update product C to no position,
the end result is B, A, D, C with order of positions 1, 2, 3, null.

If there are n existing positioned assignments, updating product to position \>= n will end with a new assignment with a position such that the order of positions is maintained.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryProductAssignmentT otherwise.
    */
  updateProductCategoryAssignment<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CategoryProductAssignmentT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategoryProductAssignmentT>;
  /**
    * Creates a category product assignment using the information provided.

As the assigned position n is a normalized target position, we'll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C at positions 1, 2, 3, and product D is assigned to
position 2, the end result is A, D, B, C with order of positions 1, 2, 3, 4.

If there are n existing positioned assignment, assigning a new product to position \>= n+1 will end
with the new assignment with position n+1.
    *
    * If you would like to get a raw Response object use the other assignProductToCategory function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CategoryProductAssignmentT | CategoryProductAssignmentT.
    */
  assignProductToCategory(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      categoryId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: CategoryProductAssignmentT;
  }): Promise<CategoryProductAssignmentT | CategoryProductAssignmentT>;
  /**
    * Creates a category product assignment using the information provided.

As the assigned position n is a normalized target position, we'll make sure that the product is assigned
to a position so that the order of positions are maintained.

For example, if we have products A, B, C at positions 1, 2, 3, and product D is assigned to
position 2, the end result is A, D, B, C with order of positions 1, 2, 3, 4.

If there are n existing positioned assignment, assigning a new product to position \>= n+1 will end
with the new assignment with position n+1.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param categoryId - The ID of the category to be created.
    * @param productId - The ID (SKU) of the requested product to assign.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryProductAssignmentT | CategoryProductAssignmentT otherwise.
    */
  assignProductToCategory<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        categoryId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: CategoryProductAssignmentT;
    },
    rawResponse?: T
  ): Promise<
    T extends true
      ? Response
      : CategoryProductAssignmentT | CategoryProductAssignmentT
  >;
  /**
    * Searches for catalog categories in the scope of catalog.
By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Using a large value for levels may cause performance
  issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
parent_category_id - String


The output of the query can also be sorted. These are the the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double
    *
    * If you would like to get a raw Response object use the other searchCategoriesInCatalog function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param levels - The level number.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CategorySearchResultT.
    */
  searchCategoriesInCatalog(options: {
    parameters?: {
      organizationId?: string;
      catalogId: string;
      levels?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<CategorySearchResultT>;
  /**
    * Searches for catalog categories in the scope of catalog.
By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Using a large value for levels may cause performance
  issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
parent_category_id - String


The output of the query can also be sorted. These are the the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param catalogId - The ID of the requested catalog.
    * @param levels - The level number.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategorySearchResultT otherwise.
    */
  searchCategoriesInCatalog<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        catalogId: string;
        levels?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategorySearchResultT>;
  /**
    * Searches for catalogs.

The query attribute specifies a complex query that can be used to narrow down the search. These are the  searchable attributes:

id - String
name - String
description - String
creation_date - DateTime


There are two additional fields that can be used as search filters. They are not attributes in CatalogWO object,
but can be used as filters to query catalogs based on site assignments.

is_master_catalog - Boolean
is_storefront_catalog - Boolean


On using is_master_catalog in the search query, catalogs without any site assignments are returned.
On using is_storefront_catalog in the search query, catalogs with one or more site assignments are returned.

The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
    *
    * If you would like to get a raw Response object use the other searchCatalogs function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CatalogSearchResultT.
    */
  searchCatalogs(options: {
    parameters?: {
      organizationId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<CatalogSearchResultT>;
  /**
    * Searches for catalogs.

The query attribute specifies a complex query that can be used to narrow down the search. These are the  searchable attributes:

id - String
name - String
description - String
creation_date - DateTime


There are two additional fields that can be used as search filters. They are not attributes in CatalogWO object,
but can be used as filters to query catalogs based on site assignments.

is_master_catalog - Boolean
is_storefront_catalog - Boolean


On using is_master_catalog in the search query, catalogs without any site assignments are returned.
On using is_storefront_catalog in the search query, catalogs with one or more site assignments are returned.

The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CatalogSearchResultT otherwise.
    */
  searchCatalogs<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CatalogSearchResultT>;
  /**
    * Searches for catalog categories anywhere they appear.
By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Please note, using a large value for levels may cause performance
  issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
catalog_id - String


The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double
    *
    * If you would like to get a raw Response object use the other searchCategories function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param levels - The level number.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type CategorySearchResultT.
    */
  searchCategories(options: {
    parameters?: {
      organizationId?: string;
      levels?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<CategorySearchResultT>;
  /**
    * Searches for catalog categories anywhere they appear.
By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Please note, using a large value for levels may cause performance
  issues with a large and deep category tree.

The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
catalog_id - String


The output of the query can also be sorted. These are the sortable attributes:

id - String
name - String
description - String
creation_date - DateTime
online - Boolean
position - Double
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param levels - The level number.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategorySearchResultT otherwise.
    */
  searchCategories<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        levels?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : CategorySearchResultT>;
}
declare namespace Catalogs {
  type Money = MoneyT;
  type CategoryProductAssignmentSearchResult = CategoryProductAssignmentSearchResultT;
  type ProductOption = ProductOptionT;
  type Master = MasterT;
  type CategorySearchResult = CategorySearchResultT;
  type Category = CategoryT;
  type VariationAttribute = VariationAttributeT;
  type CatalogCategoryId = CatalogCategoryIdT;
  type Categories = CategoriesT;
  type SortingRule = SortingRuleT;
  type ProductType = ProductTypeT;
  type Variant = VariantT;
  type VariationGroup = VariationGroupT;
  type ProductOptionValue = ProductOptionValueT;
  type VariationAttributes = VariationAttributesT;
  type CategoryLinks = CategoryLinksT;
  type MarkupText = MarkupTextT;
  type ImageGroup = ImageGroupT;
  type Catalogs = CatalogsT;
  type CategoryLink = CategoryLinkT;
  type MediaFile = MediaFileT;
  type VariationAttributeValues = VariationAttributeValuesT;
  type CatalogSearchResult = CatalogSearchResultT;
  type Site = SiteT;
  type ProductOptions = ProductOptionsT;
  type Product = ProductT;
  type CategoryProductAssignment = CategoryProductAssignmentT;
  type VariationAttributeValue = VariationAttributeValueT;
  type ProductOptionValues = ProductOptionValuesT;
  type CustomerListLink = CustomerListLinkT;
  type PathRecord = PathRecordT;
  type Catalog = CatalogT;
  type SortingRuleStep = SortingRuleStepT;
  type ErrorResponse = ErrorResponseT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type SimpleSearchResult = SimpleSearchResultT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type SearchRequest = SearchRequestT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
}
export = Catalogs;
