/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  MoneyT,
  VariantsT,
  ProductOptionT,
  MasterT,
  VariantSearchResultT,
  VariationAttributeT,
  CatalogCategoryIdT,
  ProductTypeT,
  VariantT,
  VariationGroupT,
  ProductOptionValueT,
  VariationAttributesT,
  MarkupTextT,
  ImageGroupT,
  MediaFileT,
  VariationAttributeValuesT,
  ProductSearchResultT,
  ProductOptionsT,
  ProductT,
  VariationAttributeValueT,
  ProductOptionValuesT,
  VariationGroupsT,
  ErrorResponseT,
  SimpleSearchResultT,
  SearchRequestT,
  PaginatedSearchResultT,
  BoolFilterT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT
} from "./products.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class Products extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Deletes the product by ID.
   *
   * If you would like to get a raw Response object use the other deleteProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The product ID.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteProduct(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes the product by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The product ID.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Action to get product information.
   *
   * If you would like to get a raw Response object use the other getProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The product ID.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ProductT.
   */
  getProduct(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ProductT>;
  /**
   * Action to get product information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The product ID.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductT otherwise.
   */
  getProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductT>;
  /**
    * Update a product using the information provided.

Fields that can be updated:
name, page_description, long_descripton, page_title,
page_keywords, brand, ean,upc, manufacture_sku,
manufacture_name, searchable, unit, searchable,
online_flag, default_variant_id.
    *
    * If you would like to get a raw Response object use the other updateProduct function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param productId - The product ID.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ProductT.
    */
  updateProduct(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ProductT;
  }): Promise<ProductT>;
  /**
    * Update a product using the information provided.

Fields that can be updated:
name, page_description, long_descripton, page_title,
page_keywords, brand, ean,upc, manufacture_sku,
manufacture_name, searchable, unit, searchable,
online_flag, default_variant_id.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param productId - The product ID.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ProductT otherwise.
    */
  updateProduct<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ProductT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductT>;
  /**
   * Creates a product using the information provided. If a product with the same unique identifier exists, it will be cleaned and overwritten unless the header x-dw-validate-existing=true is passed in with the request.
   *
   * If you would like to get a raw Response object use the other createProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The product ID.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ProductT | ProductT.
   */
  createProduct(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ProductT;
  }): Promise<ProductT | ProductT>;
  /**
   * Creates a product using the information provided. If a product with the same unique identifier exists, it will be cleaned and overwritten unless the header x-dw-validate-existing=true is passed in with the request.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The product ID.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductT | ProductT otherwise.
   */
  createProduct<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ProductT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductT | ProductT>;
  /**
    * Searches product variations for master product or variation group product.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 variation_attribute.ATTRIBUTE_ID (Ex:variation_attribute.color) - String
 
 Sortable Fields:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 

 Note:
 The calculated value of \"online\" and \"searchable\" is used in the search/sort.
 A search/sort by the the site specific attributes require the Site ID query parameter to be set.
 They are \"online\", \"in_stock\", \"searchable\" and \"ats\".
  We assume that every field that starts with variation_attribute. is searchable and dot is followed by ATTRIBUTE_ID\".


 The list of expansions to retrieve product information. The expand values available are:
   
  _base - Basic product information is retrieved. This expand is included by default.
  all - All product information including the following properties are retrieved:
   
   image
   price - siteId has to be provided to see this property
   price_currency - siteId has to be provided to see this property
   
  availability - Information related to the availability of the product variation.  This expand is not included by default.
   
   ats - siteId has to be provided to see this property
   in_stock - siteId has to be provided to see this property
   online - siteId has to be provided to see this property
   searchable
   
   variations - Information related to product variation is retrieved. This expand is included by default.
  attributes - Information related to product variation attributes is retrieved. This expand is not included by default.
  
    *
    * If you would like to get a raw Response object use the other searchProductVariations function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param productId - The product ID.
    * @param siteId - The site context
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type VariantSearchResultT.
    */
  searchProductVariations(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<VariantSearchResultT>;
  /**
    * Searches product variations for master product or variation group product.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 variation_attribute.ATTRIBUTE_ID (Ex:variation_attribute.color) - String
 
 Sortable Fields:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 

 Note:
 The calculated value of \"online\" and \"searchable\" is used in the search/sort.
 A search/sort by the the site specific attributes require the Site ID query parameter to be set.
 They are \"online\", \"in_stock\", \"searchable\" and \"ats\".
  We assume that every field that starts with variation_attribute. is searchable and dot is followed by ATTRIBUTE_ID\".


 The list of expansions to retrieve product information. The expand values available are:
   
  _base - Basic product information is retrieved. This expand is included by default.
  all - All product information including the following properties are retrieved:
   
   image
   price - siteId has to be provided to see this property
   price_currency - siteId has to be provided to see this property
   
  availability - Information related to the availability of the product variation.  This expand is not included by default.
   
   ats - siteId has to be provided to see this property
   in_stock - siteId has to be provided to see this property
   online - siteId has to be provided to see this property
   searchable
   
   variations - Information related to product variation is retrieved. This expand is included by default.
  attributes - Information related to product variation attributes is retrieved. This expand is not included by default.
  
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param productId - The product ID.
    * @param siteId - The site context
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type VariantSearchResultT otherwise.
    */
  searchProductVariations<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariantSearchResultT>;
  /**
   * Reads variation groups for a product master.
   *
   * If you would like to get a raw Response object use the other getVariationGroupsForMasterProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId -
   * @param siteId - The site context.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariationGroupsT.
   */
  getVariationGroupsForMasterProduct(options?: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      siteId?: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariationGroupsT>;
  /**
   * Reads variation groups for a product master.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId -
   * @param siteId - The site context.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationGroupsT otherwise.
   */
  getVariationGroupsForMasterProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        siteId?: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationGroupsT>;
  /**
    * Unassign a variation group product from a product master. The variation group product is not
  deleted: it remains as a normal product after unsassign.
    *
    * If you would like to get a raw Response object use the other unassignVariationGroupFromMasterProduct function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation group product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type void.
    */
  unassignVariationGroupFromMasterProduct(options?: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
    * Unassign a variation group product from a product master. The variation group product is not
  deleted: it remains as a normal product after unsassign.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation group product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    */
  unassignVariationGroupFromMasterProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Read a variation group for a product master.
   *
   * If you would like to get a raw Response object use the other getVariationGroupForMasterProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation group product.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariationGroupT.
   */
  getVariationGroupForMasterProduct(options?: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariationGroupT>;
  /**
   * Read a variation group for a product master.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation group product.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationGroupT otherwise.
   */
  getVariationGroupForMasterProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationGroupT>;
  /**
   * Update a variation group for a product master.
   *
   * If you would like to get a raw Response object use the other updateVariationGroupForMasterProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation group product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type VariationGroupT.
   */
  updateVariationGroupForMasterProduct(options: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariationGroupT;
  }): Promise<VariationGroupT>;
  /**
   * Update a variation group for a product master.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation group product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationGroupT otherwise.
   */
  updateVariationGroupForMasterProduct<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariationGroupT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationGroupT>;
  /**
    * Assign a variation group for a product master. If the variation group product does not initially exist,
  one is created using the body passed in.
    *
    * If you would like to get a raw Response object use the other assignVariationGroupToMasterProduct function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation group product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type VariationGroupT.
    */
  assignVariationGroupToMasterProduct(options: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariationGroupT;
  }): Promise<VariationGroupT>;
  /**
    * Assign a variation group for a product master. If the variation group product does not initially exist,
  one is created using the body passed in.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation group product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type VariationGroupT otherwise.
    */
  assignVariationGroupToMasterProduct<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariationGroupT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationGroupT>;
  /**
   * Reads variation for a product master.
   *
   * If you would like to get a raw Response object use the other getVariationsForMasterProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId -
   * @param siteId - The site context.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariantsT.
   */
  getVariationsForMasterProduct(options?: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      siteId?: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariantsT>;
  /**
   * Reads variation for a product master.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId -
   * @param siteId - The site context.
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariantsT otherwise.
   */
  getVariationsForMasterProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        siteId?: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariantsT>;
  /**
    * Unassign a variation product from a product master.  The variation product is not deleted: it remains as a
  normal product after unsassign.
    *
    * If you would like to get a raw Response object use the other unassignVariationFromMasterProduct function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    *
    * @returns A promise of type void.
    */
  unassignVariationFromMasterProduct(options?: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
    * Unassign a variation product from a product master.  The variation product is not deleted: it remains as a
  normal product after unsassign.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    */
  unassignVariationFromMasterProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Read a variation for a product master.
   *
   * If you would like to get a raw Response object use the other getVariationForMasterProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation product.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariantT.
   */
  getVariationForMasterProduct(options?: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariantT>;
  /**
   * Read a variation for a product master.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation product.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariantT otherwise.
   */
  getVariationForMasterProduct<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariantT>;
  /**
   * Update a variation for a product master.
   *
   * If you would like to get a raw Response object use the other updateVariationForMasterProduct function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type VariantT.
   */
  updateVariationForMasterProduct(options: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariantT;
  }): Promise<VariantT>;
  /**
   * Update a variation for a product master.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param masterProductId - The ID of the master product that contains the variation group.
   * @param id - The ID of the variation product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariantT otherwise.
   */
  updateVariationForMasterProduct<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariantT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariantT>;
  /**
    * Assign a variation for a product master.  If the variation product does not initially exist,
  one is created using the body passed in.
    *
    * If you would like to get a raw Response object use the other assignVariationForMasterProduct function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type VariantT.
    */
  assignVariationForMasterProduct(options: {
    parameters?: {
      organizationId?: string;
      masterProductId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariantT;
  }): Promise<VariantT>;
  /**
    * Assign a variation for a product master.  If the variation product does not initially exist,
  one is created using the body passed in.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param masterProductId - The ID of the master product that contains the variation group.
    * @param id - The ID of the variation product.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type VariantT otherwise.
    */
  assignVariationForMasterProduct<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        masterProductId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariantT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariantT>;
  /**
   * Read local and shared product options of a product.
   *
   * If you would like to get a raw Response object use the other getProductOptions function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId -
   * @param currency -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ProductOptionsT.
   */
  getProductOptions(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      currency?: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ProductOptionsT>;
  /**
   * Read local and shared product options of a product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId -
   * @param currency -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionsT otherwise.
   */
  getProductOptions<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        currency?: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductOptionsT>;
  /**
   * Deletes a local product option or unbinds a shared product option from the product.
   *
   * If you would like to get a raw Response object use the other deleteProductOption function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteProductOption(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes a local product option or unbinds a shared product option from the product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteProductOption<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Read a local or shared product option of a product.
   *
   * If you would like to get a raw Response object use the other getProductOption function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param currency -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ProductOptionT.
   */
  getProductOption(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
      currency?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ProductOptionT>;
  /**
   * Read a local or shared product option of a product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param currency -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionT otherwise.
   */
  getProductOption<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
        currency?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductOptionT>;
  /**
   * Updates a local product option with the information provided.
   *
   * If you would like to get a raw Response object use the other updateProductOption function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ProductOptionT.
   */
  updateProductOption(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ProductOptionT;
  }): Promise<ProductOptionT>;
  /**
   * Updates a local product option with the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionT otherwise.
   */
  updateProductOption<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ProductOptionT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductOptionT>;
  /**
   * Creates a local product option using the information provided or binds a shared product option to the product.
   *
   * If you would like to get a raw Response object use the other createProductOption function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ProductOptionT | ProductOptionT.
   */
  createProductOption(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ProductOptionT;
  }): Promise<ProductOptionT | ProductOptionT>;
  /**
   * Creates a local product option using the information provided or binds a shared product option to the product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the local or shared product option.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionT | ProductOptionT otherwise.
   */
  createProductOption<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ProductOptionT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductOptionT | ProductOptionT>;
  /**
   * Deletes a local product option value by ID.
   *
   * If you would like to get a raw Response object use the other deleteProductOptionValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteProductOptionValue(options?: {
    parameters?: {
      organizationId?: string;
      id: string;
      optionId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes a local product option value by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteProductOptionValue<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        id: string;
        optionId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Read a local product option value of a local product option in a product.
   *
   * If you would like to get a raw Response object use the other getProductOptionValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type ProductOptionValueT.
   */
  getProductOptionValue(options?: {
    parameters?: {
      organizationId?: string;
      id: string;
      optionId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<ProductOptionValueT>;
  /**
   * Read a local product option value of a local product option in a product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionValueT otherwise.
   */
  getProductOptionValue<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        id: string;
        optionId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductOptionValueT>;
  /**
   * Updates a local product option value with the information provided.
   *
   * If you would like to get a raw Response object use the other updateProductOptionValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ProductOptionValueT.
   */
  updateProductOptionValue(options: {
    parameters?: {
      organizationId?: string;
      id: string;
      optionId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ProductOptionValueT;
  }): Promise<ProductOptionValueT>;
  /**
   * Updates a local product option value with the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionValueT otherwise.
   */
  updateProductOptionValue<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        id: string;
        optionId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ProductOptionValueT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductOptionValueT>;
  /**
   * Creates a local product option value using the information provided.
   *
   * If you would like to get a raw Response object use the other createProductOptionValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type ProductOptionValueT | ProductOptionValueT.
   */
  createProductOptionValue(options: {
    parameters?: {
      organizationId?: string;
      id: string;
      optionId: string;
      productId: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: ProductOptionValueT;
  }): Promise<ProductOptionValueT | ProductOptionValueT>;
  /**
   * Creates a local product option value using the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the local product option value.
   * @param optionId - The ID of the local product option.
   * @param productId - The ID of the product.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type ProductOptionValueT | ProductOptionValueT otherwise.
   */
  createProductOptionValue<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        id: string;
        optionId: string;
        productId: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: ProductOptionValueT;
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : ProductOptionValueT | ProductOptionValueT
  >;
  /**
   * Action to get product variation attribute value information.
   *
   * If you would like to get a raw Response object use the other getVariationAttributeValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariationAttributeValueT.
   */
  getVariationAttributeValue(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      attributeId: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariationAttributeValueT>;
  /**
   * Action to get product variation attribute value information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param siteId - The site context.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributeValueT otherwise.
   */
  getVariationAttributeValue<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        attributeId: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationAttributeValueT>;
  /**
   * Deletes the variation attribute value of a variation attribute bound to a master product.
   *
   * If you would like to get a raw Response object use the other deleteVariationAttributeValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteVariationAttributeValue(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      attributeId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes the variation attribute value of a variation attribute bound to a master product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteVariationAttributeValue<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        attributeId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Updates the variation attribute value of a variation attribute of a master product.
   *
   * If you would like to get a raw Response object use the other updateVariationAttributeValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type VariationAttributeValueT.
   */
  updateVariationAttributeValue(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      attributeId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariationAttributeValueT;
  }): Promise<VariationAttributeValueT>;
  /**
   * Updates the variation attribute value of a variation attribute of a master product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributeValueT otherwise.
   */
  updateVariationAttributeValue<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        attributeId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariationAttributeValueT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationAttributeValueT>;
  /**
   * Action to create a product variation attribute value.
   *
   * If you would like to get a raw Response object use the other createVariationAttributeValue function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type VariationAttributeValueT | VariationAttributeValueT.
   */
  createVariationAttributeValue(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      attributeId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariationAttributeValueT;
  }): Promise<VariationAttributeValueT | VariationAttributeValueT>;
  /**
   * Action to create a product variation attribute value.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param attributeId - The variation attribute ID.
   * @param id - The ID of the variation attribute value.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributeValueT | VariationAttributeValueT otherwise.
   */
  createVariationAttributeValue<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        attributeId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariationAttributeValueT;
    },
    rawResponse?: T
  ): Promise<
    T extends true
      ? Response
      : VariationAttributeValueT | VariationAttributeValueT
  >;
  /**
   * Reads variation attributes of a product of type variant, variation master, or variation group.
   *
   * If you would like to get a raw Response object use the other getVariationAttributes function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariationAttributesT.
   */
  getVariationAttributes(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      offset?: number;
      limit?: number;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariationAttributesT>;
  /**
   * Reads variation attributes of a product of type variant, variation master, or variation group.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributesT otherwise.
   */
  getVariationAttributes<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        offset?: number;
        limit?: number;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationAttributesT>;
  /**
   * Action to get variation attribute information only for master product.
   *
   * If you would like to get a raw Response object use the other getVariationAttribute function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the variation attribute to create.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type VariationAttributeT.
   */
  getVariationAttribute(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<VariationAttributeT>;
  /**
   * Action to get variation attribute information only for master product.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the variation attribute to create.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributeT otherwise.
   */
  getVariationAttribute<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationAttributeT>;
  /**
   * Deletes the variation attribute by ID.
   *
   * If you would like to get a raw Response object use the other deleteVariationAttribute function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the variation attribute to create.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteVariationAttribute(options?: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes the variation attribute by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the variation attribute to create.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteVariationAttribute<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
    * Updates the variation attribute with the specified information.
  name
  slicing
  
    *
    * If you would like to get a raw Response object use the other updateVariationAttribute function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param productId - The ID of the product.
    * @param id - The ID of the variation attribute to create.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type VariationAttributeT.
    */
  updateVariationAttribute(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariationAttributeT;
  }): Promise<VariationAttributeT>;
  /**
    * Updates the variation attribute with the specified information.
  name
  slicing
  
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param productId - The ID of the product.
    * @param id - The ID of the variation attribute to create.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributeT otherwise.
    */
  updateVariationAttribute<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariationAttributeT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : VariationAttributeT>;
  /**
   * Creates a variation attribute using the information provided.
   *
   * If you would like to get a raw Response object use the other createVariationAttribute function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the variation attribute to create.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type VariationAttributeT | VariationAttributeT.
   */
  createVariationAttribute(options: {
    parameters?: {
      organizationId?: string;
      productId: string;
      id: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: VariationAttributeT;
  }): Promise<VariationAttributeT | VariationAttributeT>;
  /**
   * Creates a variation attribute using the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param productId - The ID of the product.
   * @param id - The ID of the variation attribute to create.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type VariationAttributeT | VariationAttributeT otherwise.
   */
  createVariationAttribute<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        productId: string;
        id: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: VariationAttributeT;
    },
    rawResponse?: T
  ): Promise<
    T extends true ? Response : VariationAttributeT | VariationAttributeT
  >;
  /**
    * "Searches for products.

 The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
 into different buckets.  These are the list of searchable attributes with their corresponding buckets:

 Main:
 
   id - String
   name - String
   online - SiteSpecific Boolean
   searchable - SiteSpecific Boolean
   valid_from - SiteSpefic DateTime
   valid_to - SiteSpecfic DateTime
   type - ProductType
   creation_date - DateTime
 
 Catalog:
 
   catalog_id - String
 
 Category:
 
   category_id - String
 
 Special:
 
   type - \{\"item\", \"set, \"bundle\", \"master\", \"part_of_product_set\", \"bundled\", \"variant\", \"variation_group\", \"option\", \"retail_set\", \"part_of_retail_set\"\}
 

 The sortable properties are:
 
 id - String
 name - String
 creation_date - DateTime
 

 Note that catalog_id is the id of the catalog to which products are assigned to.

 Only attributes in the same bucket can be joined using a disjunction (OR).
 For instance, when joining id and catalog_id above, only a conjunction is allowed (AND), whereas id
 and searchable can be joined using a disjunction because they are in the same bucket.  If an attribute
 is used in a disjunction (OR) that violates this rule, an exception will be thrown.

 The product search retrieves additional properties of the product when expansions are used.
 The available expand attribute values are:
 
   'all' will retrieve all the product properties.
   'availability' will retrieve the following properties:
   ats
   in_stock
   online
   
   'categories' will retrieve the following properties:
   assigned_categories
 
   'images' will retrieve the following properties:
   image
 
 'all_images' used with images will retrieve the following properties:
   image
   image_groups
 
   'prices' will retrieve the following properties:
   price
   price_currency
 
   'sets' will retrieve the following properties:
   set_products
   product_sets
 
   'bundles' will retrieve the following properties:
   product_bundles
   bundled_products
   
 

 \"

    *
    * If you would like to get a raw Response object use the other searchProducts function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId - The site context.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type ProductSearchResultT.
    */
  searchProducts(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<ProductSearchResultT>;
  /**
    * "Searches for products.

 The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
 into different buckets.  These are the list of searchable attributes with their corresponding buckets:

 Main:
 
   id - String
   name - String
   online - SiteSpecific Boolean
   searchable - SiteSpecific Boolean
   valid_from - SiteSpefic DateTime
   valid_to - SiteSpecfic DateTime
   type - ProductType
   creation_date - DateTime
 
 Catalog:
 
   catalog_id - String
 
 Category:
 
   category_id - String
 
 Special:
 
   type - \{\"item\", \"set, \"bundle\", \"master\", \"part_of_product_set\", \"bundled\", \"variant\", \"variation_group\", \"option\", \"retail_set\", \"part_of_retail_set\"\}
 

 The sortable properties are:
 
 id - String
 name - String
 creation_date - DateTime
 

 Note that catalog_id is the id of the catalog to which products are assigned to.

 Only attributes in the same bucket can be joined using a disjunction (OR).
 For instance, when joining id and catalog_id above, only a conjunction is allowed (AND), whereas id
 and searchable can be joined using a disjunction because they are in the same bucket.  If an attribute
 is used in a disjunction (OR) that violates this rule, an exception will be thrown.

 The product search retrieves additional properties of the product when expansions are used.
 The available expand attribute values are:
 
   'all' will retrieve all the product properties.
   'availability' will retrieve the following properties:
   ats
   in_stock
   online
   
   'categories' will retrieve the following properties:
   assigned_categories
 
   'images' will retrieve the following properties:
   image
 
 'all_images' used with images will retrieve the following properties:
   image
   image_groups
 
   'prices' will retrieve the following properties:
   price
   price_currency
 
   'sets' will retrieve the following properties:
   set_products
   product_sets
 
   'bundles' will retrieve the following properties:
   product_bundles
   bundled_products
   
 

 \"

    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId - The site context.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ProductSearchResultT otherwise.
    */
  searchProducts<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : ProductSearchResultT>;
}
declare namespace Products {
  type Money = MoneyT;
  type Variants = VariantsT;
  type ProductOption = ProductOptionT;
  type Master = MasterT;
  type VariantSearchResult = VariantSearchResultT;
  type VariationAttribute = VariationAttributeT;
  type CatalogCategoryId = CatalogCategoryIdT;
  type ProductType = ProductTypeT;
  type Variant = VariantT;
  type VariationGroup = VariationGroupT;
  type ProductOptionValue = ProductOptionValueT;
  type VariationAttributes = VariationAttributesT;
  type MarkupText = MarkupTextT;
  type ImageGroup = ImageGroupT;
  type MediaFile = MediaFileT;
  type VariationAttributeValues = VariationAttributeValuesT;
  type ProductSearchResult = ProductSearchResultT;
  type ProductOptions = ProductOptionsT;
  type Product = ProductT;
  type VariationAttributeValue = VariationAttributeValueT;
  type ProductOptionValues = ProductOptionValuesT;
  type VariationGroups = VariationGroupsT;
  type ErrorResponse = ErrorResponseT;
  type SimpleSearchResult = SimpleSearchResultT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type BoolFilter = BoolFilterT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
}
export = Products;
