/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type MoneyT = {
  currencyMnemonic: string;
  value: number;
} & {
  [key: string]: any;
};
export declare type VariantsT = {
  limit: number;
  data: Array<VariantT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ProductOptionT = {
  customName?: {} & {
    [key: string]: any;
  };
  defaultProductOptionValue?: string;
  description?: {} & {
    [key: string]: any;
  };
  id: string;
  image?: MediaFileT;
  name?: string;
  selectedOptionValue?: string;
  shared?: boolean;
  sortingMode?: string;
  values?: Array<ProductOptionValueT>;
} & {
  [key: string]: any;
};
export declare type MasterT = {
  masterId: string;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariantSearchResultT = {
  hits: Array<VariantT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type VariationAttributeT = {
  attributeDefinitionId: string;
  attributeDefinitionName?: {} & {
    [key: string]: any;
  };
  defaultValue?: string;
  id?: string;
  name?: {} & {
    [key: string]: any;
  };
  shared?: boolean;
  slicing?: boolean;
  values?: Array<VariationAttributeValueT>;
  variationAttributeType?: string;
} & {
  [key: string]: any;
};
export declare type CatalogCategoryIdT = {
  catalogId: string;
  categoryId: string;
} & {
  [key: string]: any;
};
export declare type ProductTypeT = {
  bundle?: boolean;
  bundled?: boolean;
  item?: boolean;
  master: boolean;
  option?: boolean;
  partOfProductSet?: boolean;
  partOfRetailSet?: boolean;
  retailSet?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
} & {
  [key: string]: any;
};
export declare type VariantT = {
  ats?: number;
  defaultProductVariation?: boolean;
  image?: MediaFileT;
  inStock?: boolean;
  online?: boolean;
  orderable?: boolean;
  price?: number;
  priceCurrency?: string;
  productId: string;
  searchable?: {} & {
    [key: string]: any;
  };
  variationAttributes?: Array<VariationAttributeT>;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationGroupT = {
  orderable?: boolean;
  price?: number;
  productId: string;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type ProductOptionValueT = {
  defaultProductOptionValue?: boolean;
  id: string;
  optionPrices?: Array<MoneyT>;
  skuExtension?: string;
  value: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationAttributesT = {
  limit: number;
  data: Array<VariationAttributeT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type MarkupTextT = {
  markup: string;
  source: string;
} & {
  [key: string]: any;
};
export declare type ImageGroupT = {
  images: Array<MediaFileT>;
  variationAttributes?: Array<VariationAttributeT>;
  viewType: string;
} & {
  [key: string]: any;
};
export declare type MediaFileT = {
  absUrl?: string;
  alt?: {} & {
    [key: string]: any;
  };
  disBaseUrl?: string;
  path: string;
  title?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationAttributeValuesT = {
  limit: number;
  data: Array<VariationAttributeValueT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ProductSearchResultT = {
  hits: Array<ProductT>;
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ProductOptionsT = {
  limit: number;
  data: Array<ProductOptionT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ProductT = {
  assignedCategories?: Array<CatalogCategoryIdT>;
  ats?: number;
  brand?: string;
  bundledProducts?: Array<ProductT>;
  creationDate?: any;
  defaultVariantId?: string;
  ean?: string;
  id: string;
  image?: MediaFileT;
  imageGroups?: Array<ImageGroupT>;
  inStock?: boolean;
  lastModified?: any;
  longDescription?: {} & {
    [key: string]: any;
  };
  manufacturerName?: string;
  manufacturerSku?: string;
  master?: MasterT;
  name?: {} & {
    [key: string]: any;
  };
  online?: boolean;
  onlineFlag?: {} & {
    [key: string]: any;
  };
  owningCatalogId?: string;
  owningCatalogName?: {} & {
    [key: string]: any;
  };
  pageDescription?: {} & {
    [key: string]: any;
  };
  pageKeywords?: {} & {
    [key: string]: any;
  };
  pageTitle?: {} & {
    [key: string]: any;
  };
  price?: number;
  priceCurrency?: string;
  primaryCategoryId?: string;
  productBundles?: Array<ProductT>;
  productOptions?: Array<ProductOptionT>;
  productSets?: Array<ProductT>;
  searchable?: {} & {
    [key: string]: any;
  };
  setProducts?: Array<ProductT>;
  shortDescription?: {} & {
    [key: string]: any;
  };
  type?: ProductTypeT;
  unit?: string;
  upc?: string;
  variants?: Array<VariantT>;
  variationAttributes?: Array<VariationAttributeT>;
  variationGroups?: Array<VariationGroupT>;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationAttributeValueT = {
  description?: {} & {
    [key: string]: any;
  };
  image?: MediaFileT;
  imageSwatch?: MediaFileT;
  name?: {} & {
    [key: string]: any;
  };
  orderable?: boolean;
  position?: number;
  value: string;
} & {
  [key: string]: any;
};
export declare type ProductOptionValuesT = {
  limit: number;
  data: Array<ProductOptionValueT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type VariationGroupsT = {
  limit: number;
  data: Array<VariationGroupT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
