/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type OptionValueT = {
  default?: boolean;
  id: string;
  name?: string;
  price?: number;
} & {
  [key: string]: any;
};
export declare type MasterT = {
  masterId: string;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type CategoryT = {
  categories?: Array<CategoryT>;
  description?: string;
  id: string;
  image?: string;
  name?: string;
  pageDescription?: string;
  pageKeywords?: string;
  pageTitle?: string;
  parentCategoryId?: string;
  thumbnail?: string;
} & {
  [key: string]: any;
};
export declare type CategoryResultT = {
  limit: number;
  data: Array<CategoryT>;
  total: number;
} & {
  [key: string]: any;
};
export declare type VariationAttributeT = {
  id: string;
  name?: string;
  values?: Array<VariationAttributeValueT>;
} & {
  [key: string]: any;
};
export declare type RecommendationTypeT = {
  displayValue: string;
  value: number;
} & {
  [key: string]: any;
};
export declare type ProductTypeT = {
  bundle?: boolean;
  item?: boolean;
  master?: boolean;
  option?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
} & {
  [key: string]: any;
};
export declare type RecommendationT = {
  calloutMsg?: string;
  image?: ImageT;
  longDescription?: string;
  name?: string;
  recommendationType: RecommendationTypeT;
  recommendedItemId?: string;
  shortDescription?: string;
} & {
  [key: string]: any;
};
export declare type VariantT = {
  orderable?: boolean;
  price?: number;
  productId: string;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type VariationGroupT = {
  orderable: boolean;
  price: number;
  productId: string;
  variationValues: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type ProductResultT = {
  limit: number;
  data: Array<ProductT>;
  total: number;
} & {
  [key: string]: any;
};
export declare type ProductLinkT = {
  sourceProductId: string;
  sourceProductLink: string;
  targetProductId: string;
  targetProductLink: string;
  type: string;
} & {
  [key: string]: any;
};
export declare type InventoryT = {
  ats?: number;
  backorderable?: boolean;
  id: string;
  inStockDate?: any;
  orderable?: boolean;
  preorderable?: boolean;
  stockLevel?: number;
} & {
  [key: string]: any;
};
export declare type ImageGroupT = {
  images: Array<ImageT>;
  variationAttributes?: Array<VariationAttributeT>;
  viewType: string;
} & {
  [key: string]: any;
};
export declare type OptionT = {
  description?: string;
  id: string;
  image?: string;
  name?: string;
  values?: Array<OptionValueT>;
} & {
  [key: string]: any;
};
export declare type ProductT = {
  brand?: string;
  bundledProducts?: Array<BundledProductT>;
  currency?: string;
  ean?: string;
  fetchDate?: number;
  id: string;
  imageGroups?: Array<ImageGroupT>;
  inventories?: Array<InventoryT>;
  inventory?: InventoryT;
  longDescription?: string;
  manufacturerName?: string;
  manufacturerSku?: string;
  master?: MasterT;
  minOrderQuantity?: number;
  name?: string;
  options?: Array<OptionT>;
  pageDescription?: string;
  pageKeywords?: string;
  pageTitle?: string;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
  primaryCategoryId?: string;
  productLinks?: Array<ProductLinkT>;
  productPromotions?: Array<ProductPromotionT>;
  recommendations?: Array<RecommendationT>;
  setProducts?: Array<ProductT>;
  shortDescription?: string;
  stepQuantity?: number;
  type?: ProductTypeT;
  unit?: string;
  upc?: string;
  validFrom?: any;
  validTo?: any;
  variants?: Array<VariantT>;
  variationAttributes?: Array<VariationAttributeT>;
  variationGroups?: Array<VariationGroupT>;
  variationValues?: {} & {
    [key: string]: any;
  };
} & {
  [key: string]: any;
};
export declare type ImageT = {
  alt?: string;
  disBaseLink?: string;
  link: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type VariationAttributeValueT = {
  description?: string;
  image?: ImageT;
  imageSwatch?: ImageT;
  name?: string;
  orderable?: boolean;
  value: string;
} & {
  [key: string]: any;
};
export declare type ProductPromotionT = {
  calloutMsg: string;
  promotionId: string;
  promotionalPrice: number;
} & {
  [key: string]: any;
};
export declare type BundledProductT = {
  id: string;
  product: ProductT;
  quantity: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
