/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type ProductRefT = {
  id: string;
} & {
  [key: string]: any;
};
export declare type SuggestedTermsT = {
  originalTerm: string;
  terms?: Array<SuggestedTermT>;
} & {
  [key: string]: any;
};
export declare type CategorySuggestionsT = {
  categories?: Array<SuggestedCategoryT>;
  suggestedPhrases?: Array<SuggestedPhraseT>;
  suggestedTerms: Array<SuggestedTermsT>;
} & {
  [key: string]: any;
};
export declare type SuggestedProductT = {
  currency: string;
  image?: ImageT;
  price: number;
  productId: string;
  productName: string;
} & {
  [key: string]: any;
};
export declare type SuggestedPhraseT = {
  exactMatch: boolean;
  phrase: string;
} & {
  [key: string]: any;
};
export declare type VariationAttributeT = {
  id: string;
  name?: string;
  values?: Array<VariationAttributeValueT>;
} & {
  [key: string]: any;
};
export declare type ProductSuggestionsT = {
  products?: Array<SuggestedProductT>;
  suggestedPhrases?: Array<SuggestedPhraseT>;
  suggestedTerms: Array<SuggestedTermsT>;
} & {
  [key: string]: any;
};
export declare type SuggestedCategoryT = {
  id: string;
  name: string;
  parentCategoryName: string;
} & {
  [key: string]: any;
};
export declare type ProductTypeT = {
  bundle?: boolean;
  item?: boolean;
  master?: boolean;
  option?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
} & {
  [key: string]: any;
};
export declare type BrandSuggestionsT = {} & {
  [key: string]: any;
};
export declare type ProductSearchRefinementValueT = {
  description?: string;
  hitCount: number;
  label: string;
  presentationId?: string;
  value: string;
  values?: Array<ProductSearchRefinementValueT>;
} & {
  [key: string]: any;
};
export declare type ProductSearchSortingOptionT = {
  id: string;
  label: string;
} & {
  [key: string]: any;
};
export declare type SuggestedTermT = {
  completed: boolean;
  corrected: boolean;
  exactMatch: boolean;
  value: string;
} & {
  [key: string]: any;
};
export declare type ProductSearchRefinementT = {
  attributeId: string;
  label?: string;
  values?: Array<ProductSearchRefinementValueT>;
} & {
  [key: string]: any;
};
export declare type CustomSuggestionsT = {
  customSuggestion?: string;
  suggestedPhrases?: Array<SuggestedPhraseT>;
  suggestedTerms: Array<SuggestedTermsT>;
} & {
  [key: string]: any;
};
export declare type ProductSearchHitT = {
  currency?: string;
  hitType?: string;
  image?: ImageT;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: {} & {
    [key: string]: any;
  };
  productId: string;
  productName?: string;
  productType?: ProductTypeT;
  representedProduct?: ProductRefT;
  representedProducts?: Array<ProductRefT>;
  variationAttributes?: Array<VariationAttributeT>;
} & {
  [key: string]: any;
};
export declare type ProductSearchResultT = {
  limit: number;
  hits: Array<ProductSearchHitT>;
  query: string;
  refinements: Array<ProductSearchRefinementT>;
  searchPhraseSuggestions: SuggestionT;
  selectedRefinements?: {} & {
    [key: string]: any;
  };
  selectedSortingOption?: string;
  sortingOptions: Array<ProductSearchSortingOptionT>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type ImageT = {
  alt?: string;
  disBaseLink?: string;
  link: string;
  title?: string;
} & {
  [key: string]: any;
};
export declare type VariationAttributeValueT = {
  description?: string;
  image?: ImageT;
  imageSwatch?: ImageT;
  name?: string;
  orderable?: boolean;
  value: string;
} & {
  [key: string]: any;
};
export declare type SuggestionT = {
  suggestedPhrases?: Array<SuggestedPhraseT>;
  suggestedTerms: Array<SuggestedTermsT>;
} & {
  [key: string]: any;
};
export declare type SuggestionResultT = {
  brandSuggestions?: BrandSuggestionsT;
  categorySuggestions?: CategorySuggestionsT;
  productSuggestions?: ProductSuggestionsT;
  customSuggestion?: CustomSuggestionsT;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type MoneyT = {
  currencyMnemonic?: string;
  value?: number;
} & {
  [key: string]: any;
};
export declare type SimpleSearchResultT = {
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type SearchRequestT = {
  limit?: number;
  query: any;
  sorts?: Array<SortT>;
  offset?: number;
} & {
  [key: string]: any;
};
export declare type PaginatedSearchResultT = {
  query: any;
  sorts?: Array<SortT>;
  limit: number;
  hits?: Array<object>;
  offset: number;
  total: number;
} & {
  [key: string]: any;
};
export declare type BoolFilterT = {
  filters?: Array<any>;
  operator: string;
} & {
  [key: string]: any;
};
export declare type MatchAllQueryT = {} & {
  [key: string]: any;
};
export declare type FilteredQueryT = {
  filter: any;
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryFilterT = {
  query: any;
} & {
  [key: string]: any;
};
export declare type QueryT = {
  boolQuery?: BoolQueryT;
  filteredQuery?: FilteredQueryT;
  matchAllQuery?: MatchAllQueryT;
  nestedQuery?: NestedQueryT;
  termQuery?: TermQueryT;
  textQuery?: TextQueryT;
} & {
  [key: string]: any;
};
export declare type TermQueryT = {
  fields: Array<string>;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TermFilterT = {
  field: string;
  operator: string;
  values?: Array<any>;
} & {
  [key: string]: any;
};
export declare type TextQueryT = {
  fields: Array<string>;
  searchPhrase: string;
} & {
  [key: string]: any;
};
export declare type Range2FilterT = {
  filterMode?: string;
  fromField: string;
  fromInclusive?: boolean;
  fromValue?: any;
  toField: string;
  toInclusive?: boolean;
  toValue?: any;
} & {
  [key: string]: any;
};
export declare type BoolQueryT = {
  must?: Array<any>;
  mustNot?: Array<any>;
  should?: Array<any>;
} & {
  [key: string]: any;
};
export declare type NestedQueryT = {
  path: string;
  query: any;
  scoreMode?: string;
} & {
  [key: string]: any;
};
export declare type FilterT = {
  boolFilter?: BoolFilterT;
  queryFilter?: QueryFilterT;
  range2Filter?: Range2FilterT;
  rangeFilter?: RangeFilterT;
  termFilter?: TermFilterT;
} & {
  [key: string]: any;
};
export declare type SortT = {
  field: string;
  sortOrder?: string;
} & {
  [key: string]: any;
};
export declare type RangeFilterT = {
  field: string;
  from?: any;
  fromInclusive?: boolean;
  to?: any;
  toInclusive?: boolean;
} & {
  [key: string]: any;
};
export declare type ErrorResponseT = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
} & {
  [key: string]: any;
};
